@@ -15,6 +15,8 @@ where :math:`\tau(E, z)` is the optical depth predicted by the model
 (`~gammapy.modeling.models.EBLAbsorptionNormSpectralModel`), which depends on the energy of the gamma-rays and the
 redshift z of the source, and :math:`\alpha` is a scale factor
 (default: 1) for the optical depth.
+
+The available EBL models are defined in `~gammapy.modeling.models.spectral.EBL_DATA_BUILTIN`.
 """
 
 # %%
@@ -30,6 +32,10 @@ from gammapy.modeling.models import (
     PowerLawSpectralModel,
     SkyModel,
 )
+from gammapy.modeling.models.spectral import EBL_DATA_BUILTIN
+
+# Print the available EBL models
+print(EBL_DATA_BUILTIN.keys())
 
 # Here we illustrate how to create and plot EBL absorption models for a redshift of 0.5
 # sphinx_gallery_thumbnail_number = 1
@@ -40,6 +46,12 @@ franceschini = EBLAbsorptionNormSpectralModel.read_builtin(
     "franceschini", redshift=redshift
 )
 finke = EBLAbsorptionNormSpectralModel.read_builtin("finke", redshift=redshift)
+franceschini17 = EBLAbsorptionNormSpectralModel.read_builtin(
+    "franceschini17", redshift=redshift
+)
+saldana21 = EBLAbsorptionNormSpectralModel.read_builtin(
+    "saldana-lopez21", redshift=redshift
+)
 
 fig, (ax_ebl, ax_model) = plt.subplots(
     nrows=1, ncols=2, figsize=(10, 4), gridspec_kw={"left": 0.08, "right": 0.96}
@@ -51,6 +63,8 @@ opts = dict(energy_bounds=energy_bounds, xunits=u.TeV)
 franceschini.plot(ax=ax_ebl, label="Franceschini 2008", **opts)
 finke.plot(ax=ax_ebl, label="Finke 2010", **opts)
 dominguez.plot(ax=ax_ebl, label="Dominguez 2011", **opts)
+franceschini17.plot(ax=ax_ebl, label="Franceschni 2017", **opts)
+saldana21.plot(ax=ax_ebl, label="Saldana-Lopez 2021", **opts)
 
 ax_ebl.set_ylabel(r"Absorption coefficient [$\exp{(-\tau(E))}$]")
 ax_ebl.set_xlim(energy_bounds.value)
