@@ -20,7 +20,7 @@ Context
 -------
 
 As already explained in the :doc:`/tutorials/analysis-1d/spectral_analysis`
-tutorial, the background is estimated fromthe field of view of the observation.
+tutorial, the background is estimated from the field of view of the observation.
 In particular, the source and background events are counted within a circular 
 ON region enclosing the source. The background to be subtracted is then estimated
 from one or more OFF regions with an expected background rate similar to the one
@@ -168,6 +168,7 @@ print(rad_max)
 
 fig, ax = plt.subplots()
 rad_max.plot_rad_max_vs_energy(ax=ax)
+plt.show()
 
 
 ######################################################################
@@ -248,10 +249,10 @@ for observation in observations:
 # map:
 #
 
-plt.figure()
 ax = counts.plot(cmap="viridis")
 geom.plot_region(ax=ax, kwargs_point={"color": "k", "marker": "*"})
 plot_spectrum_datasets_off_regions(ax=ax, datasets=datasets)
+plt.show()
 
 
 ######################################################################
@@ -312,6 +313,7 @@ display(datasets.models.to_parameters_table())
 #
 ax_spectrum, ax_residuals = datasets[0].plot_fit()
 ax_spectrum.set_ylim(0.1, 120)
+plt.show()
 
 
 ######################################################################
@@ -349,4 +351,32 @@ ax.legend()
 ax.set_ylim([1e-13, 1e-10])
 plt.show()
 
+
+######################################################################
+# Dataset simulations
+# -------------------
+#
+# A common way to check if a fit is biased is to simulate multiple datasets with
+# the obtained best fit model, and check the distribution of the fitted parameters.
+# Here, we show how to perform one such simulation assuming the measured off counts
+# provide a good distribution of the background.
+#
+
+dataset_simulated = datasets.stack_reduce().copy(name="simulated_ds")
+simulated_model = best_fit_model.copy(name="simulated")
+dataset_simulated.models = simulated_model
+dataset_simulated.fake(
+    npred_background=dataset_simulated.counts_off * dataset_simulated.alpha
+)
+dataset_simulated.peek()
+plt.show()
+
+# The important thing to note here is that while this samples the on-counts, the off counts are
+# not sampled. If you have multiple measurements of the off counts, they should be used.
+# Alternatively, you can try to create a parametric model of the background.
+
+result = fit.run(datasets=[dataset_simulated])
+print(result.models.to_parameters_table())
+
+
 # sphinx_gallery_thumbnail_number = 4
