@@ -13,8 +13,8 @@ instance the first analysis tutorial.
 Context
 -------
 
-A useful tool to study and compare the saptial distribution of flux in
-images and data cubes is the measurement of flxu profiles. Flux profiles
+A useful tool to study and compare the spatial distribution of flux in
+images and data cubes is the measurement of flux profiles. Flux profiles
 can show spatial correlations of gamma-ray data with e.g. gas maps or
 other type of gamma-ray data. Most commonly flux profiles are measured
 along some preferred coordinate axis, either radially distance from a
@@ -31,7 +31,7 @@ linear profiles it’s typically a rectangular shape.
 
 We will work on a pre-computed `~gammapy.datasets.MapDataset` of Fermi-LAT data, use
 `~regions.SkyRegion` to define the structure of the bins of the flux profile and
-run the actually profile extraction using the `~gammapy.estimators.FluxProfileEstimator`
+run the flux profile extraction using the `~gammapy.estimators.FluxProfileEstimator`
 
 """
 
@@ -80,6 +80,7 @@ dataset = MapDataset.read(
 #
 counts_image = dataset.counts.sum_over_axes()
 counts_image.smooth("0.1 deg").plot(stretch="sqrt")
+plt.show()
 
 
 ######################################################################
@@ -101,7 +102,7 @@ print(dataset.counts)
 # galactic longitude axis. For this there is a helper function
 # `~gammapy.utils.regions.make_orthogonal_rectangle_sky_regions`. The individual region bins
 # for the profile have a height of 3 deg and in total there are 31 bins.
-# The starts from lon = 10 deg tand goes to lon = 350 deg. In addition we
+# Its starts from lon = 10 deg and goes to lon = 350 deg. In addition, we
 # have to specify the `wcs` to take into account possible projections
 # effects on the region definition:
 #
@@ -120,10 +121,10 @@ regions = make_orthogonal_rectangle_sky_regions(
 # the counts image:
 #
 
-plt.figure()
 geom = RegionGeom.create(region=regions)
 ax = counts_image.smooth("0.1 deg").plot(stretch="sqrt")
 geom.plot_region(ax=ax, color="w")
+plt.show()
 
 
 ######################################################################
@@ -170,9 +171,9 @@ print(profile)
 #
 # Let us directly plot the result using `~gammapy.estimators.FluxPoints.plot`:
 #
-plt.figure()
 ax = profile.plot(sed_type="dnde")
 ax.set_yscale("linear")
+plt.show()
 
 
 ######################################################################
@@ -186,6 +187,7 @@ profile.sqrt_ts_threshold_ul = 2
 plt.figure()
 ax = profile.plot(sed_type="eflux")
 ax.set_yscale("linear")
+plt.show()
 
 
 ######################################################################
@@ -202,6 +204,7 @@ for quantity in quantities:
     profile[quantity].plot(ax=ax, label=quantity.title())
 
 ax.set_ylabel("Counts")
+plt.show()
 
 
 ######################################################################
@@ -221,9 +224,9 @@ profile.write(
 
 profile_new = FluxPoints.read(filename="flux_profile_fermi.fits", format="profile")
 
-fig = plt.figure()
 ax = profile_new.plot()
 ax.set_yscale("linear")
+plt.show()
 
 
 ######################################################################
@@ -250,13 +253,13 @@ regions = make_concentric_annulus_sky_regions(
 ######################################################################
 # Again we first illustrate the regions:
 #
-plt.figure()
 geom = RegionGeom.create(region=regions)
 gc_image = counts_image.cutout(
     position=SkyCoord("0d", "0d", frame="galactic"), width=3 * u.deg
 )
 ax = gc_image.smooth("0.1 deg").plot(stretch="sqrt")
 geom.plot_region(ax=ax, color="w")
+plt.show()
 
 
 ######################################################################
@@ -279,8 +282,8 @@ profile = flux_profile_estimator.run(datasets=dataset)
 # We can directly plot the result:
 #
 
-plt.figure()
 profile.plot(axis_name="projected-distance", sed_type="flux")
+plt.show()
 
 
 ######################################################################
@@ -289,6 +292,7 @@ profile.plot(axis_name="projected-distance", sed_type="flux")
 #
 
 profile_high = profile.slice_by_idx({"energy": slice(1, 2)})
+plt.show()
 
 
 ######################################################################
@@ -299,8 +303,6 @@ fig, ax = plt.subplots()
 profile_high.plot(ax=ax, sed_type="eflux", color="tab:orange")
 profile_high.plot_ts_profiles(ax=ax, sed_type="eflux")
 ax.set_yscale("linear")
-
-
 plt.show()
 
 # sphinx_gallery_thumbnail_number = 2
