@@ -83,7 +83,7 @@ log = logging.getLogger(__name__)
 from gammapy.data import Observation, observatory_locations
 from gammapy.datasets import Datasets, FluxPointsDataset, SpectrumDataset
 from gammapy.estimators import LightCurveEstimator
-from gammapy.irf import load_cta_irfs
+from gammapy.irf import load_irf_dict_from_file
 from gammapy.makers import SpectrumDatasetMaker
 from gammapy.maps import MapAxis, RegionGeom, TimeMapAxis
 from gammapy.modeling import Fit
@@ -119,7 +119,7 @@ TimeMapAxis.time_format = "iso"
 #
 
 # Loading IRFs
-irfs = load_cta_irfs(
+irfs = load_irf_dict_from_file(
     "$GAMMAPY_DATA/cta-1dc/caldb/data/cta/1dc/bcf/South_z20_50h/irf_file.fits"
 )
 
@@ -218,7 +218,7 @@ display(datasets.info_table())
 # extraction. Only a spectral model needs to be defined in this case.
 # Since the estimator returns the integrated flux separately for each time
 # bin, the temporal model need not be accounted for at this stage. We
-# extract the lightcurve in 3 energy binsç
+# extract the lightcurve in 3 energy bins.
 #
 
 # Define the model:
@@ -243,6 +243,7 @@ fig, ax = plt.subplots(
     gridspec_kw={"left": 0.16, "bottom": 0.2, "top": 0.98, "right": 0.98},
 )
 lc_1d.plot(ax=ax, marker="o", axis_name="time", sed_type="flux")
+plt.show()
 
 
 ######################################################################
@@ -318,6 +319,7 @@ temporal_model1.plot(ax=ax, time_range=time_range, label="Best fit model")
 
 ax.set_yscale("linear")
 ax.legend()
+plt.show()
 
 
 ######################################################################
@@ -355,7 +357,6 @@ result = fit.run(datasets=datasets)
 
 display(result.parameters.to_table())
 
-plt.show()
 ######################################################################
 # We see that the fitted parameters are consistent between fitting flux
 # points and datasets, and match well with the simulated ones
