@@ -30,7 +30,7 @@ example in https://arxiv.org/pdf/1012.4515.pdf (Chapter 1 and 5)
 import numpy as np
 import astropy.units as u
 from astropy.coordinates import SkyCoord
-from regions import CircleSkyRegion
+from regions import CircleSkyRegion, RectangleSkyRegion
 
 # %matplotlib inline
 import matplotlib.pyplot as plt
@@ -63,7 +63,6 @@ check_tutorials_setup()
 
 profiles.DMProfile.__subclasses__()
 
-plt.figure()
 for profile in profiles.DMProfile.__subclasses__():
     p = profile()
     p.scale_to_local_density()
@@ -73,6 +72,7 @@ for profile in profiles.DMProfile.__subclasses__():
 plt.loglog()
 plt.axvline(8.5, linestyle="dashed", color="black", label="local density")
 plt.legend()
+plt.show()
 
 print("LOCAL_DENSITY:", profiles.DMProfile.LOCAL_DENSITY)
 print("DISTANCE_GC:", profiles.DMProfile.DISTANCE_GC)
@@ -87,7 +87,7 @@ print("DISTANCE_GC:", profiles.DMProfile.DISTANCE_GC)
 # J-Factor map for the Galactic Centre region
 #
 
-profile = profiles.NFWProfile()
+profile = profiles.NFWProfile(r_s=20 * u.kpc)
 
 # Adopt standard values used in HESS
 profiles.DMProfile.DISTANCE_GC = 8.5 * u.kpc
@@ -106,20 +106,32 @@ plt.figure()
 ax = jfact_map.plot(cmap="viridis", norm=LogNorm(), add_cbar=True)
 plt.title(f"J-Factor [{jfact_map.unit}]")
 
-# 1 deg circle usually used in H.E.S.S. analyses
+# 1 deg circle usually used in H.E.S.S. analyses without the +/- 0.3 deg band around the plane
 sky_reg = CircleSkyRegion(center=position, radius=1 * u.deg)
 pix_reg = sky_reg.to_pixel(wcs=geom.wcs)
 pix_reg.plot(ax=ax, facecolor="none", edgecolor="red", label="1 deg circle")
-plt.legend()
 
-# NOTE: https://arxiv.org/abs/1607.08142 quote 2.67e21 without the +/- 0.3 deg band around the plane
-total_jfact = pix_reg.to_mask().multiply(jfact).sum()
+sky_reg_rec = RectangleSkyRegion(center=position, height=0.6 * u.deg, width=2 * u.deg)
+pix_reg_rec = sky_reg_rec.to_pixel(wcs=geom.wcs)
+pix_reg_rec.plot(ax=ax, facecolor="none", edgecolor="orange", label="+/- 0.3 deg band")
+
+plt.legend()
+plt.show()
+
+# NOTE: https://arxiv.org/abs/1607.08142 quote 2.67e21
+total_jfact = (
+    pix_reg.to_mask().multiply(jfact).sum()
+    - pix_reg_rec.to_mask().multiply(jfact).sum()
+)
+total_jfact = (
+    pix_reg.to_mask().multiply(jfact).sum()
+    - pix_reg_rec.to_mask().multiply(jfact).sum()
+)
 print(
-    "J-factor in 1 deg circle around GC assuming a "
+    "J-factor in 1 deg circle without the +/- 0.3 deg band around GC assuming a "
     f"{profile.__class__.__name__} is {total_jfact:.3g}"
 )
 
-
 ######################################################################
 # Gamma-ray spectra at production
 # -------------------------------
@@ -152,6 +164,7 @@ for mDM, ax in zip(mDMs, axes):
 
 axes[0].legend()
 plt.subplots_adjust(hspace=0.9)
+plt.show()
 
 
 ######################################################################
