@@ -8,12 +8,12 @@ Introduction
 ------------
 
 `~gammapy.catalog` provides convenient access to common gamma-ray
-source catalogs. This module is mostly independent from the rest of
-Gammapy. Typically you use it to compare new analyses against catalog
-results, e.g. overplot the spectral model, or compare the source
+source catalogs. This module is mostly independent of the rest of
+Gammapy. Typically, you use it to compare new analyses against catalog
+results, e.g. overplot the spectral model, or compare the source
 position.
 
-Moreover as creating a source model and flux points for a given catalog
+Moreover, as creating a source model and flux points for a given catalog
 from the FITS table is tedious, `~gammapy.catalog` has this already
 implemented. So you can create initial source models for your analyses.
 This is very common for Fermi-LAT, to start with a catalog model. For
@@ -41,7 +41,7 @@ In this tutorial we will show examples using the following catalogs:
 
 All catalog and source classes work the same, as long as some
 information is available. E.g. trying to access a lightcurve from a
-catalog and source that doesn’t have that information will return
+catalog and source that does not have that information will return
 `None`.
 
 Further information is available at `~gammapy.catalog`.
@@ -298,11 +298,11 @@ print(model.spatial_model)
 print(model.spectral_model)
 
 # %%
-plt.figure()
 energy_bounds = (100 * u.MeV, 100 * u.GeV)
 opts = dict(sed_type="e2dnde", yunits=u.Unit("TeV cm-2 s-1"))
 model.spectral_model.plot(energy_bounds, **opts)
 model.spectral_model.plot_error(energy_bounds, **opts)
+plt.show()
 
 
 ######################################################################
@@ -376,8 +376,8 @@ print(flux_points)
 display(flux_points.to_table(sed_type="flux"))
 
 # %%
-plt.figure()
 flux_points.plot(sed_type="e2dnde")
+plt.show()
 
 
 ######################################################################
@@ -397,8 +397,8 @@ print(lightcurve)
 display(lightcurve.to_table(format="lightcurve", sed_type="flux"))
 
 # %%
-plt.figure()
 lightcurve.plot()
+plt.show()
 
 
 ######################################################################
@@ -422,6 +422,3 @@ help(source.info)
 
 # %%
 print(source.info("associations"))
-
-# %%
-plt.show()
