@@ -157,9 +157,8 @@ counts.fill_events(events)
 
 print(counts.geom.axes[0])
 
-plt.figure()
 counts.sum_over_axes().smooth(2).plot(stretch="sqrt", vmax=30)
-
+plt.show()
 
 ######################################################################
 # Exposure
@@ -189,8 +188,8 @@ exposure_hpx = Map.read("$GAMMAPY_DATA/fermi_3fhl/fermi_3fhl_exposure_cube_hpx.f
 print(exposure_hpx.geom)
 print(exposure_hpx.geom.axes[0])
 
-plt.figure()
 exposure_hpx.plot()
+plt.show()
 
 ######################################################################
 # For exposure, we choose a geometry with node_type='center',
@@ -210,8 +209,8 @@ print(exposure.geom.axes[0])
 
 ######################################################################
 # Exposure is almost constant across the field of view
-plt.figure()
 exposure.slice_by_idx({"energy_true": 0}).plot(add_cbar=True)
+plt.show()
 
 ######################################################################
 # Exposure varies very little with energy at these high energies
@@ -253,8 +252,8 @@ diffuse_iem = SkyModel(
 ######################################################################
 # Let’s look at the map of first energy band of the cube:
 #
-plt.figure()
 template_diffuse.map.slice_by_idx({"energy_true": 0}).plot(add_cbar=True)
+plt.show()
 
 
 ######################################################################
@@ -262,10 +261,10 @@ template_diffuse.map.slice_by_idx({"energy_true": 0}).plot(add_cbar=True)
 #
 
 dnde = template_diffuse.map.to_region_nd_map(region=gc_pos)
-plt.figure()
 dnde.plot()
 plt.xlabel("Energy (GeV)")
 plt.ylabel("Flux (cm-2 s-1 MeV-1 sr-1)")
+plt.show()
 
 
 ######################################################################
@@ -287,9 +286,9 @@ diffuse_iso = create_fermi_isotropic_diffuse_model(
 ######################################################################
 # We can plot the model in the energy range between 50 GeV and 2000 GeV:
 #
-plt.figure()
 energy_bounds = [50, 2000] * u.GeV
 diffuse_iso.spectral_model.plot(energy_bounds, yunits=u.Unit("1 / (cm2 MeV s)"))
+plt.show()
 
 
 ######################################################################
@@ -316,6 +315,7 @@ print(psf)
 
 plt.figure(figsize=(8, 5))
 psf.plot_containment_radius_vs_energy()
+plt.show()
 
 
 ######################################################################
@@ -335,16 +335,17 @@ psf_mean.plot_psf_vs_rad(c="k", ls="--", energy_true=[500] * u.GeV)
 plt.xlim(1e-3, 0.3)
 plt.ylim(1e3, 1e6)
 plt.legend()
+plt.show()
 
 ######################################################################
-# This is whaty the corresponding PSF kernel looks like:
+# This is what the corresponding PSF kernel looks like:
 #
 
 psf_kernel = psf.get_psf_kernel(
     position=geom.center_skydir, geom=geom, max_radius="1 deg"
 )
-plt.figure()
 psf_kernel.to_image().psf_kernel_map.plot(stretch="log", add_cbar=True)
+plt.show()
 
 
 ######################################################################
@@ -359,8 +360,8 @@ edisp = EDispKernelMap.from_diagonal_response(
     energy_axis_true=e_true, energy_axis=energy_axis
 )
 
-plt.figure()
 edisp.get_edisp_kernel().plot_matrix()
+plt.show()
 
 
 ######################################################################
@@ -404,10 +405,10 @@ print(models)
 
 residual = counts - dataset.npred()
 
-plt.figure()
 residual.sum_over_axes().smooth("0.1 deg").plot(
     cmap="coolwarm", vmin=-3, vmax=3, add_cbar=True
 )
+plt.show()
 
 ######################################################################
 # Serialisation
@@ -425,7 +426,7 @@ datasets_read = Datasets.read(
 )
 print(datasets_read)
 
-plt.show()
+
 ######################################################################
 # Exercises
 # ---------
