@@ -40,6 +40,8 @@ release 1.
 
 import astropy.units as u
 from astropy.coordinates import SkyCoord
+
+# %matplotlib inline
 import matplotlib.pyplot as plt
 from IPython.display import display
 from gammapy.data import DataStore
@@ -74,7 +76,7 @@ data_store = DataStore.from_dir("$GAMMAPY_DATA/hess-dl3-dr1")
 data_store.info()
 
 ######################################################################
-# Preview an excerpt from the observtaion table
+# Preview an excerpt from the observation table
 
 display(data_store.obs_table[:2][["OBS_ID", "DATE-OBS", "RA_PNT", "DEC_PNT", "OBJECT"]])
 
@@ -104,9 +106,8 @@ obs.psf.peek()
 
 ######################################################################
 # Peek the background rate
-plt.figure()
 obs.bkg.to_2d().plot()
-
+plt.show()
 
 ######################################################################
 # Theta squared event distribution
@@ -128,7 +129,7 @@ theta2_table = make_theta_squared_table(
 
 plt.figure(figsize=(10, 5))
 plot_theta_squared_table(theta2_table)
-
+plt.show()
 
 ######################################################################
 # On-axis equivalent livetime
@@ -169,7 +170,9 @@ geom = WcsGeom.create(
 # compute
 livetime = Map.from_geom(geom, unit=u.hr)
 for obs in observations:
-    geom_obs = geom.cutout(position=obs.pointing_radec, width=2.0 * offset_max)
+    geom_obs = geom.cutout(
+        position=obs.get_pointing_icrs(obs.tmid), width=2.0 * offset_max
+    )
     exposure = MapDatasetMaker.make_exposure(geom=geom_obs, observation=obs)
     on_axis = obs.aeff.evaluate(
         offset=0.0 * u.deg, energy_true=geom.axes["energy_true"].center
@@ -179,18 +182,17 @@ for obs in observations:
     livetime.stack(lv_obs)
 
 # Plot
-plt.figure()
 ax = livetime.plot(add_cbar=True)
+plt.show()
 
 # Add the pointing position on top
 for obs in observations:
     ax.plot(
-        obs.pointing_radec.to_pixel(wcs=ax.wcs)[0],
-        obs.pointing_radec.to_pixel(wcs=ax.wcs)[1],
+        obs.get_pointing_icrs(obs.tmid).to_pixel(wcs=ax.wcs)[0],
+        obs.get_pointing_icrs(obs.tmid).to_pixel(wcs=ax.wcs)[1],
         "+",
         color="black",
     )
-
 plt.show()
 
 ######################################################################
