@@ -78,6 +78,7 @@ from regions import CircleSkyRegion
 
 # %matplotlib inline
 import matplotlib.pyplot as plt
+from IPython.display import display
 from gammapy.data import DataStore
 from gammapy.datasets import MapDataset
 from gammapy.estimators import FluxPointsEstimator
@@ -91,6 +92,7 @@ from gammapy.modeling.models import (
     SkyModel,
 )
 from gammapy.utils.check import check_tutorials_setup
+from gammapy.visualization import plot_npred_signal
 
 ######################################################################
 # Check setup
@@ -206,7 +208,7 @@ maker_fov = FoVBackgroundMaker(method="fit", exclusion_mask=exclusion_mask)
 for obs in observations:
     # First a cutout of the target map is produced
     cutout = stacked.cutout(
-        obs.pointing_radec, width=2 * offset_max, name=f"obs-{obs.obs_id}"
+        obs.get_pointing_icrs(obs.tmid), width=2 * offset_max, name=f"obs-{obs.obs_id}"
     )
     # A MapDataset is filled in this cutout geometry
     dataset = maker.run(cutout, obs)
@@ -229,6 +231,7 @@ print(stacked)
 #
 
 stacked.counts.sum_over_axes().smooth(0.05 * u.deg).plot(stretch="sqrt", add_cbar=True)
+plt.show()
 
 
 ######################################################################
@@ -318,6 +321,16 @@ print(result)
 print(stacked.models.to_parameters_table())
 
 
+######################################################################
+# Here we can plot the number of predicted counts for each model and
+# for the background in our dataset. In order to do this, we can use
+# the `~gammapy.visualization.plot_npred_signal` function.
+#
+
+plot_npred_signal(stacked)
+plt.show()
+
+
 ######################################################################
 # Inspecting residuals
 # ~~~~~~~~~~~~~~~~~~~~
@@ -329,6 +342,7 @@ print(stacked.models.to_parameters_table())
 #
 
 stacked.plot_residuals_spatial(method="diff/sqrt(model)", vmin=-0.5, vmax=0.5)
+plt.show()
 
 
 ######################################################################
@@ -342,6 +356,7 @@ stacked.plot_residuals(
     kwargs_spatial=dict(method="diff/sqrt(model)", vmin=-0.5, vmax=0.5),
     kwargs_spectral=dict(region=region),
 )
+plt.show()
 
 
 ######################################################################
@@ -353,7 +368,7 @@ residuals = stacked.residuals(method="diff")
 residuals.smooth("0.08 deg").plot_interactive(
     cmap="coolwarm", vmin=-0.2, vmax=0.2, stretch="linear", add_cbar=True
 )
-
+plt.show()
 
 ######################################################################
 # Plot the fitted spectrum
@@ -380,6 +395,7 @@ spec = sky_model.spectral_model
 energy_bounds = [1, 10] * u.TeV
 spec.plot(energy_bounds=energy_bounds, energy_power=2)
 ax = spec.plot_error(energy_bounds=energy_bounds, energy_power=2)
+plt.show()
 
 
 ######################################################################
@@ -402,3 +418,4 @@ flux_points = fpe.run(datasets=[stacked])
 
 ax = spec.plot_error(energy_bounds=energy_bounds, energy_power=2)
 flux_points.plot(ax=ax, energy_power=2)
+plt.show()
