@@ -4,7 +4,7 @@ import abc
 import numpy as np
 import astropy.units as u
 from gammapy.modeling import Parameter, Parameters
-from gammapy.modeling.models.spectral import integrate_spectrum
+from gammapy.utils.integrate import trapz_loglog
 
 __all__ = [
     "BurkertProfile",
@@ -34,11 +34,15 @@ class DMProfile(abc.ABC):
         scale = (self.LOCAL_DENSITY / self(self.DISTANCE_GC)).to_value("")
         self.parameters["rho_s"].value *= scale
 
-    def _eval_squared(self, radius):
-        """Squared density at given radius."""
-        return self(radius) ** 2
+    def _eval_squared(self, radius, separation):
+        """Squared density at given radius together with the substitution part"""
+        return (
+            self(radius) ** 2
+            * radius
+            / np.sqrt(radius**2 - (self.DISTANCE_GC * np.sin(separation)) ** 2)
+        )
 
-    def integral(self, rmin, rmax, **kwargs):
+    def integral(self, rmin, rmax, separation, ndecade):
         r"""Integrate squared dark matter profile numerically.
 
         .. math::
@@ -48,12 +52,40 @@ class DMProfile(abc.ABC):
         ----------
         rmin, rmax : `~astropy.units.Quantity`
             Lower and upper bound of integration range.
-        **kwargs : dict
-            Keyword arguments passed to :func:`~gammapy.utils.integrate.integrate_spectrum`
+        separation : `~numpy.ndarray`
+            Separation angle in rad
+        ndecade    : int, optional
+            Number of grid points per decade used for the integration.
+            Default : 10000
         """
-        integral = integrate_spectrum(self._eval_squared, rmin, rmax, **kwargs)
+        integral = self.integrate_spectrum_separation(
+            self._eval_squared, rmin, rmax, separation, ndecade
+        )
         return integral.to("GeV2 / cm5")
 
+    def integrate_spectrum_separation(self, func, xmin, xmax, separation, ndecade):
+        r"""Helper for the squared dark matter profile integral.
+
+        Parameters
+        ----------
+        xmin, xmax : `~astropy.units.Quantity`
+            Lower and upper bound of integration range.
+        separation : `~numpy.ndarray`
+            Separation angle in rad
+        ndecade    : int
+            Number of grid points per decade used for the integration.
+        """
+        unit = xmin.unit
+        xmin = xmin.value
+        xmax = xmax.to_value(unit)
+        logmin = np.log10(xmin)
+        logmax = np.log10(xmax)
+        n = np.int32((logmax - logmin) * ndecade)
+        x = np.logspace(logmin, logmax, n) * unit
+        y = func(x, separation)
+        val = trapz_loglog(y, x)
+        return val.sum()
+
 
 class NFWProfile(DMProfile):
     r"""NFW Profile.
