@@ -1,5 +1,6 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 """Utilities to compute J-factor maps."""
+import numpy as np
 import astropy.units as u
 
 __all__ = ["JFactory"]
@@ -26,22 +27,40 @@ class JFactory:
         self.profile = profile
         self.distance = distance
 
-    def compute_differential_jfactor(self):
+    def compute_differential_jfactor(self, ndecade=1e4):
         r"""Compute differential J-Factor.
 
         .. math::
             \frac{\mathrm d J}{\mathrm d \Omega} =
-            \int_{\mathrm{LoS}} \mathrm d r \rho(r)
+            \int_{\mathrm{LoS}} \mathrm d l \rho(l)^2
         """
-        # TODO: Needs to be implemented more efficiently
-        separation = self.geom.separation(self.geom.center_skydir)
-        rmin = separation.rad * self.distance
+        separation = self.geom.separation(self.geom.center_skydir).rad
+        rmin = u.Quantity(
+            value=np.tan(separation) * self.distance, unit=self.distance.unit
+        )
         rmax = self.distance
-        val = [self.profile.integral(_, rmax) for _ in rmin.flatten()]
+        val = [
+            (
+                2
+                * self.profile.integral(
+                    _.value * u.kpc,
+                    rmax,
+                    np.arctan(_.value / self.distance.value),
+                    ndecade,
+                )
+                + self.profile.integral(
+                    self.distance,
+                    4 * rmax,
+                    np.arctan(_.value / self.distance.value),
+                    ndecade,
+                )
+            )
+            for _ in rmin.ravel()
+        ]
         jfact = u.Quantity(val).to("GeV2 cm-5").reshape(rmin.shape)
         return jfact / u.steradian
 
-    def compute_jfactor(self):
+    def compute_jfactor(self, ndecade=1e4):
         r"""Compute astrophysical J-Factor.
 
         .. math::
@@ -49,5 +68,5 @@ class JFactory:
            \int_{\Delta\Omega} \mathrm d \Omega^{\prime}
            \frac{\mathrm d J}{\mathrm d \Omega^{\prime}}
         """
-        diff_jfact = self.compute_differential_jfactor()
+        diff_jfact = self.compute_differential_jfactor(ndecade)
         return diff_jfact * self.geom.to_image().solid_angle()
