@@ -23,6 +23,7 @@ from gammapy.utils.gauss import Gauss2DPDF
 from gammapy.utils.testing import (
     assert_quantity_allclose,
     assert_time_allclose,
+    modify_unit_order_astropy_5_3,
     requires_data,
 )
 
@@ -162,8 +163,11 @@ class TestFermi4FGLObject:
     @pytest.mark.parametrize("ref", SOURCES_4FGL, ids=lambda _: _["name"])
     def test_str(self, ref):
         actual = str(self.cat[ref["idx"]])
-        expected = open(get_pkg_data_filename(ref["str_ref_file"])).read()
-        assert actual == expected
+
+        with open(get_pkg_data_filename(ref["str_ref_file"])) as fh:
+            expected = fh.read()
+
+        assert actual == modify_unit_order_astropy_5_3(expected)
 
     @pytest.mark.parametrize("ref", SOURCES_4FGL, ids=lambda _: _["name"])
     def test_spectral_model(self, ref):
@@ -349,8 +353,11 @@ class TestFermi3FGLObject:
     @pytest.mark.parametrize("ref", SOURCES_3FGL, ids=lambda _: _["name"])
     def test_str(self, ref):
         actual = str(self.cat[ref["idx"]])
-        expected = open(get_pkg_data_filename(ref["str_ref_file"])).read()
-        assert actual == expected
+
+        with open(get_pkg_data_filename(ref["str_ref_file"])) as fh:
+            expected = fh.read()
+
+        assert actual == modify_unit_order_astropy_5_3(expected)
 
     @pytest.mark.parametrize("ref", SOURCES_3FGL, ids=lambda _: _["name"])
     def test_spectral_model(self, ref):
@@ -483,8 +490,11 @@ class TestFermi2FHLObject:
     @pytest.mark.parametrize("ref", SOURCES_2FHL, ids=lambda _: _["name"])
     def test_str(self, ref):
         actual = str(self.cat[ref["idx"]])
-        expected = open(get_pkg_data_filename(ref["str_ref_file"])).read()
-        assert actual == expected
+
+        with open(get_pkg_data_filename(ref["str_ref_file"])) as fh:
+            expected = fh.read()
+
+        assert actual == modify_unit_order_astropy_5_3(expected)
 
     def test_spectral_model(self):
         model = self.source.spectral_model()
@@ -567,8 +577,11 @@ class TestFermi3FHLObject:
 
     def test_str(self):
         actual = str(self.cat["3FHL J2301.9+5855e"])  # an extended source
-        expected = open(get_pkg_data_filename("data/3fhl_j2301.9+5855e.txt")).read()
-        assert actual == expected
+
+        with open(get_pkg_data_filename("data/3fhl_j2301.9+5855e.txt")) as fh:
+            expected = fh.read()
+
+        assert actual == modify_unit_order_astropy_5_3(expected)
 
     def test_position(self):
         position = self.source.position
