@@ -6,8 +6,12 @@ import astropy.units as u
 from astropy.coordinates import EarthLocation, SkyCoord
 from astropy.time import Time
 from astropy.units import Quantity
-from gammapy.data import DataStore, Observation
-from gammapy.irf import PSF3D, load_cta_irfs
+from gammapy.data import DataStore, Observation, ObservationFilter
+from gammapy.data.pointing import FixedPointingInfo, PointingMode
+from gammapy.data.utils import get_irfs_features
+from gammapy.irf import PSF3D, load_irf_dict_from_file
+from gammapy.utils.cluster import hierarchical_clustering
+from gammapy.utils.deprecation import GammapyDeprecationWarning
 from gammapy.utils.fits import HDULocation
 from gammapy.utils.testing import (
     assert_skycoord_allclose,
@@ -31,10 +35,14 @@ def test_observation(data_store):
     assert_time_allclose(obs.tstop, Time(53343.94186555556, scale="tt", format="mjd"))
 
     c = SkyCoord(83.63333129882812, 21.51444435119629, unit="deg")
-    assert_skycoord_allclose(obs.pointing_radec, c)
+    assert_skycoord_allclose(obs.get_pointing_icrs(obs.tmid), c)
+    with pytest.warns(GammapyDeprecationWarning):
+        assert_skycoord_allclose(obs.pointing_radec, c)
 
     c = SkyCoord(22.558341, 41.950807, unit="deg")
-    assert_skycoord_allclose(obs.pointing_altaz, c)
+    assert_skycoord_allclose(obs.get_pointing_altaz(obs.tmid), c)
+    with pytest.warns(GammapyDeprecationWarning):
+        assert_skycoord_allclose(obs.pointing_altaz, c)
 
     c = SkyCoord(83.63333129882812, 22.01444435119629, unit="deg")
     assert_skycoord_allclose(obs.target_radec, c)
@@ -218,8 +226,11 @@ def test_observations_select_time_time_intervals_list(data_store):
 @requires_data()
 def test_observation_cta_1dc():
     ontime = 5.0 * u.hr
-    pointing = SkyCoord(0, 0, unit="deg", frame="galactic")
-    irfs = load_cta_irfs(
+    pointing = FixedPointingInfo(
+        mode=PointingMode.POINTING,
+        fixed_icrs=SkyCoord(0, 0, unit="deg", frame="galactic").icrs,
+    )
+    irfs = load_irf_dict_from_file(
         "$GAMMAPY_DATA/cta-1dc/caldb/data/cta/1dc/bcf/South_z20_50h/irf_file.fits"
     )
 
@@ -237,16 +248,20 @@ def test_observation_cta_1dc():
         location=location,
     )
 
-    assert_skycoord_allclose(obs.pointing_radec, pointing.icrs)
+    assert_skycoord_allclose(obs.get_pointing_icrs(obs.tmid), pointing.fixed_icrs)
     assert_allclose(obs.observation_live_time_duration, 0.9 * ontime)
     assert_allclose(obs.target_radec.ra, np.nan)
-    assert not np.isnan(obs.pointing_zen)
+    with pytest.warns(GammapyDeprecationWarning):
+        assert not np.isnan(obs.pointing_zen)
     assert_allclose(obs.muoneff, 1)
 
 
 @requires_data()
 def test_observation_create_radmax():
-    pointing = SkyCoord(0, 0, unit="deg", frame="galactic")
+    pointing = FixedPointingInfo(
+        mode=PointingMode.POINTING,
+        fixed_icrs=SkyCoord(0, 0, unit="deg", frame="galactic").icrs,
+    )
     obs = Observation.read("$GAMMAPY_DATA/joint-crab/dl3/magic/run_05029748_DL3.fits")
     livetime = 5.0 * u.hr
     deadtime = 0.5
@@ -262,7 +277,7 @@ def test_observation_create_radmax():
         livetime=livetime,
     )
 
-    assert_skycoord_allclose(obs1.pointing_radec, pointing.icrs)
+    assert_skycoord_allclose(obs1.get_pointing_icrs(obs1.tmid), pointing.fixed_icrs)
     assert_allclose(obs1.observation_live_time_duration, 0.5 * livetime)
     assert obs1.rad_max is not None
     assert obs1.psf is None
@@ -318,7 +333,7 @@ def test_observation_read_single_file_fixed_rad_max():
 
 @requires_data()
 class TestObservationChecker:
-    def setup(self):
+    def setup_method(self):
         self.data_store = DataStore.from_dir("$GAMMAPY_DATA/cta-1dc/index/gps")
 
     def test_check_all(self):
@@ -386,3 +401,103 @@ def test_obervation_copy(data_store):
     obs_copy = obs.copy(obs_id=1234, in_memory=True)
     assert isinstance(obs_copy.__dict__["psf"], PSF3D)
     assert obs_copy.obs_id == 1234
+
+
+def test_observation_tmid():
+    from gammapy.data import GTI
+
+    start = Time("2020-01-01T20:00:00")
+    stop = Time("2020-01-01T20:10:00")
+    expected = Time("2020-01-01T20:05:00")
+    epoch = Time("2020-01-01T00:00:00")
+
+    gti = GTI.create([(start - epoch).to(u.s)], [(stop - epoch).to(u.s)], epoch)
+    obs = Observation(gti=gti)
+    assert abs(obs.tmid - expected).to(u.ns) < 1 * u.us
+
+
+@requires_data()
+def test_observations_clustering(data_store):
+
+    selection = dict(
+        type="sky_circle",
+        frame="icrs",
+        lon="83.633 deg",
+        lat="22.014 deg",
+        radius="2 deg",
+    )
+    obs_table = data_store.obs_table.select_observations(selection)
+    observations = data_store.get_observations(obs_table["OBS_ID"])
+
+    coord = SkyCoord(83.63308, 22.01450, unit="deg", frame="icrs")
+    names = ["edisp-bias", "edisp-res", "psf-radius"]
+    features = get_irfs_features(
+        observations, energy_true="1 TeV", position=coord, names=names
+    )
+
+    n_features = len(names)
+    features_array = np.array(
+        [
+            features[col].data
+            for col in features.columns
+            if col not in ["obs_id", "dataset_name"]
+        ]
+    ).T
+    assert features_array.shape == (len(observations), n_features)
+
+    features = hierarchical_clustering(
+        features, linkage_kwargs={"method": "complete"}, fcluster_kwargs={"t": 2}
+    )
+
+    assert np.all(
+        features["labels"].data
+        == np.array(
+            [
+                1,
+                1,
+                2,
+                2,
+            ]
+        )
+    )
+
+    features = get_irfs_features(
+        observations,
+        energy_true="1 TeV",
+        position=coord,
+        names=names,
+        apply_standard_scaler=True,
+    )
+    features = hierarchical_clustering(features)
+    features_array = np.array(
+        [
+            features[col].data
+            for col in features.columns
+            if col not in ["obs_id", "dataset_name"]
+        ]
+    ).T
+
+    obs_clusters = observations.group_by_label(features["labels"])
+    for k in range(n_features):
+        assert_allclose(features_array[:, k].mean(), 0, atol=1e-7)
+        assert_allclose(features_array[:, k].std(), 1, atol=1e-7)
+
+    assert np.all(features["labels"].data == np.array([2, 1, 1, 1]))
+
+    assert len(obs_clusters["group_1"]) == 3
+    assert len(obs_clusters["group_2"]) == 1
+    assert obs_clusters["group_2"][0].obs_id == 23523
+
+
+@requires_data()
+def test_filter_live_time_phase(data_store):
+    observation = data_store.obs(20136)
+    phase_filter = {"type": "custom", "opts": dict(parameter="PHASE", band=(0.2, 0.8))}
+
+    default_obs_live_time = observation.observation_live_time_duration
+
+    obs_filter = ObservationFilter(event_filters=[phase_filter])
+    observation.obs_filter = obs_filter
+    live_time_filter = observation.observation_live_time_duration
+
+    assert_allclose(live_time_filter, default_obs_live_time * (0.8 - 0.2))
