@@ -8,7 +8,7 @@ from regions import CircleSkyRegion
 import matplotlib.pyplot as plt
 from gammapy.data import GTI
 from gammapy.irf import EDispKernelMap, EDispMap, PSFKernel, PSFMap, RecoPSFMap
-from gammapy.maps import Map, MapAxis
+from gammapy.maps import LabelMapAxis, Map, MapAxis
 from gammapy.modeling.models import DatasetModels, FoVBackgroundModel
 from gammapy.stats import (
     CashCountsStatistic,
@@ -18,6 +18,7 @@ from gammapy.stats import (
     get_wstat_mu_bkg,
     wstat,
 )
+from gammapy.utils.deprecation import deprecated_renamed_argument
 from gammapy.utils.fits import HDULocation, LazyFitsData
 from gammapy.utils.random import get_random_state
 from gammapy.utils.scripts import make_name, make_path
@@ -39,7 +40,7 @@ MIGRA_AXIS_DEFAULT = MapAxis.from_bounds(
     0.2, 5, nbin=48, node_type="edges", name="migra"
 )
 
-BINSZ_IRF_DEFAULT = 0.2
+BINSZ_IRF_DEFAULT = 0.2 * u.deg
 
 EVALUATION_MODE = "local"
 USE_NPRED_CACHE = True
@@ -50,9 +51,10 @@ def create_map_dataset_geoms(
     energy_axis_true=None,
     migra_axis=None,
     rad_axis=None,
-    binsz_irf=None,
+    binsz_irf=BINSZ_IRF_DEFAULT,
+    reco_psf=False,
 ):
-    """Create map geometries for a `MapDataset`
+    """Create map geometries for a `MapDataset`.
 
     Parameters
     ----------
@@ -67,11 +69,13 @@ def create_map_dataset_geoms(
         Rad axis for the psf map
     binsz_irf : float
         IRF Map pixel size in degrees.
+    reco_psf : bool
+        Use reconstructed energy for the PSF geometry. Default is False
 
     Returns
     -------
     geoms : dict
-        Dict with map geometries.
+        Dict with map geometries
     """
     rad_axis = rad_axis or RAD_AXIS_DEFAULT
 
@@ -80,11 +84,14 @@ def create_map_dataset_geoms(
     else:
         energy_axis_true = geom.axes["energy"].copy(name="energy_true")
 
-    binsz_irf = binsz_irf or BINSZ_IRF_DEFAULT
     geom_image = geom.to_image()
     geom_exposure = geom_image.to_cube([energy_axis_true])
     geom_irf = geom_image.to_binsz(binsz=binsz_irf)
-    geom_psf = geom_irf.to_cube([rad_axis, energy_axis_true])
+
+    if reco_psf:
+        geom_psf = geom_irf.to_cube([rad_axis, geom.axes["energy"]])
+    else:
+        geom_psf = geom_irf.to_cube([rad_axis, energy_axis_true])
 
     if migra_axis:
         geom_edisp = geom_irf.to_cube([migra_axis, energy_axis_true])
@@ -100,9 +107,14 @@ def create_map_dataset_geoms(
 
 
 class MapDataset(Dataset):
-    """
-    Bundle together binned counts, background, IRFs, models and compute a likelihood.
-     Uses Cash statistics by default.
+    """Main map dataset for likelihood fitting.
+
+    It bundles together binned counts, background, IRFs in the form of `~gammapy.maps.Map`.
+    A safe mask and a fit mask can be added to exclude bins during the analysis.
+    If models are assigned to it, it can compute predicted counts in each bin of the  counts `Map` and compute
+    the associated statistic function, here the Cash statistic (see `~gammapy.stats.cash`).
+
+    For more information see :ref:`datasets`.
 
     Parameters
     ----------
@@ -128,6 +140,7 @@ class MapDataset(Dataset):
         Table listing information on observations used to create the dataset.
         One line per observation for stacked datasets.
 
+
     If an `HDULocation` is passed the map is loaded lazily. This means the
     map data is only loaded in memory as the corresponding data attribute
     on the MapDataset is accessed. If it was accessed once it is cached for
@@ -291,7 +304,7 @@ class MapDataset(Dataset):
 
     @property
     def geoms(self):
-        """Map geometries
+        """Map geometries.
 
         Returns
         -------
@@ -320,7 +333,7 @@ class MapDataset(Dataset):
 
     @property
     def excess(self):
-        """Observed excess: counts-background"""
+        """Observed excess: counts-background."""
         return self.counts - self.background
 
     @models.setter
@@ -346,12 +359,12 @@ class MapDataset(Dataset):
 
     @property
     def evaluators(self):
-        """Model evaluators"""
+        """Model evaluators."""
         return self._evaluators
 
     @property
     def _geom(self):
-        """Main analysis geometry"""
+        """Main analysis geometry."""
         if self.counts is not None:
             return self.counts.geom
         elif self.background is not None:
@@ -368,7 +381,7 @@ class MapDataset(Dataset):
 
     @property
     def data_shape(self):
-        """Shape of the counts or background data (tuple)"""
+        """Shape of the counts or background data (tuple)."""
         return self._geom.data_shape
 
     def _energy_range(self, mask_map=None):
@@ -424,7 +437,7 @@ class MapDataset(Dataset):
         return np.nanmin(energy_min_map.quantity), np.nanmax(energy_max_map.quantity)
 
     def npred(self):
-        """Total predicted source and background counts
+        """Total predicted source and background counts.
 
         Returns
         -------
@@ -439,7 +452,7 @@ class MapDataset(Dataset):
         return npred_total
 
     def npred_background(self):
-        """Predicted background counts
+        """Predicted background counts.
 
         The predicted background counts depend on the parameters
         of the `FoVBackgroundModel` defined in the dataset.
@@ -473,18 +486,21 @@ class MapDataset(Dataset):
             self._background_parameters_cached = values
         return changed
 
-    def npred_signal(self, model_name=None):
+    @deprecated_renamed_argument("model_name", "model_names", "1.1")
+    def npred_signal(self, model_names=None, stack=True):
         """Model predicted signal counts.
 
-        If a model name is passed, predicted counts from that component are returned.
-        Else, the total signal counts are returned.
+        If a list of model name is passed, predicted counts from these components are returned.
+        If stack is set to True, a map of the sum of all the predicted counts is returned.
+        If stack is set to False, a map with an additional axis representing the models is returned.
 
         Parameters
         ----------
-        model_name: str
-            Name of  SkyModel for which to compute the npred for.
-            If none, the sum of all components (minus the background model)
-            is returned
+        model_names: list of str
+            List of name of  SkyModel for which to compute the npred.
+            If none, all the SkyModel predicted counts are computed
+        stack: bool
+            Whether to stack the npred maps upon each other.
 
         Returns
         -------
@@ -494,10 +510,14 @@ class MapDataset(Dataset):
         npred_total = Map.from_geom(self._geom, dtype=float)
 
         evaluators = self.evaluators
-        if model_name is not None:
-            evaluators = {model_name: self.evaluators[model_name]}
+        if model_names is not None:
+            if isinstance(model_names, str):
+                model_names = [model_names]
+            evaluators = {name: self.evaluators[name] for name in model_names}
 
-        for evaluator in evaluators.values():
+        npred_list = []
+        labels = []
+        for evaluator_name, evaluator in evaluators.items():
             if evaluator.needs_update:
                 evaluator.update(
                     self.exposure,
@@ -509,7 +529,17 @@ class MapDataset(Dataset):
 
             if evaluator.contributes:
                 npred = evaluator.compute_npred()
-                npred_total.stack(npred)
+                if stack:
+                    npred_total.stack(npred)
+                else:
+                    npred_geom = Map.from_geom(self._geom, dtype=float)
+                    npred_geom.stack(npred)
+                    labels.append(evaluator_name)
+                    npred_list.append(npred_geom)
+
+        if npred_list != []:
+            label_axis = LabelMapAxis(labels=labels, name="models")
+            npred_total = Map.from_stack(npred_list, axis=label_axis)
 
         return npred_total
 
@@ -525,7 +555,7 @@ class MapDataset(Dataset):
         **kwargs,
     ):
         """
-        Create a MapDataset object with zero filled maps according to the specified geometries
+        Create a MapDataset object with zero filled maps according to the specified geometries.
 
         Parameters
         ----------
@@ -582,10 +612,11 @@ class MapDataset(Dataset):
         energy_axis_true=None,
         migra_axis=None,
         rad_axis=None,
-        binsz_irf=None,
+        binsz_irf=BINSZ_IRF_DEFAULT,
         reference_time="2000-01-01",
         name=None,
         meta_table=None,
+        reco_psf=False,
         **kwargs,
     ):
         """Create a MapDataset object with zero filled maps.
@@ -610,6 +641,8 @@ class MapDataset(Dataset):
         meta_table : `~astropy.table.Table`
             Table listing information on observations used to create the dataset.
             One line per observation for stacked datasets.
+        reco_psf : bool
+            Use reconstructed energy for the PSF geometry. Default is False
 
         Returns
         -------
@@ -641,6 +674,7 @@ class MapDataset(Dataset):
             rad_axis=rad_axis,
             migra_axis=migra_axis,
             binsz_irf=binsz_irf,
+            reco_psf=reco_psf,
         )
 
         kwargs.update(geoms)
@@ -650,21 +684,21 @@ class MapDataset(Dataset):
 
     @property
     def mask_safe_image(self):
-        """Reduced mask safe"""
+        """Reduced safe mask."""
         if self.mask_safe is None:
             return None
         return self.mask_safe.reduce_over_axes(func=np.logical_or)
 
     @property
     def mask_fit_image(self):
-        """Reduced mask fit"""
+        """Reduced fit mask."""
         if self.mask_fit is None:
             return None
         return self.mask_fit.reduce_over_axes(func=np.logical_or)
 
     @property
     def mask_image(self):
-        """Reduced mask"""
+        """Reduced mask."""
         if self.mask is None:
             mask = Map.from_geom(self._geom.to_image(), dtype=bool)
             mask.data |= True
@@ -674,7 +708,7 @@ class MapDataset(Dataset):
 
     @property
     def mask_safe_psf(self):
-        """Mask safe for psf maps"""
+        """Safe mask for psf maps."""
         if self.mask_safe is None or self.psf is None:
             return None
 
@@ -684,7 +718,7 @@ class MapDataset(Dataset):
 
     @property
     def mask_safe_edisp(self):
-        """Mask safe for edisp maps"""
+        """Safe mask for edisp maps."""
         if self.mask_safe is None or self.edisp is None:
             return None
 
@@ -701,7 +735,7 @@ class MapDataset(Dataset):
         return self.mask_safe.interp_to_geom(geom)
 
     def to_masked(self, name=None, nan_to_num=True):
-        """Return masked dataset
+        """Return masked dataset.
 
         Parameters
         ----------
@@ -815,7 +849,7 @@ class MapDataset(Dataset):
             self.meta_table = other.meta_table.copy()
 
     def stat_array(self):
-        """Statistic function value per bin given the current model parameters"""
+        """Statistic function value per bin given the current model parameters."""
         return cash(n_on=self.counts.data, mu_on=self.npred().data)
 
     def residuals(self, method="diff", **kwargs):
@@ -1144,7 +1178,7 @@ class MapDataset(Dataset):
             hdulist += self.mask_fit.to_hdulist(hdu="mask_fit")[exclude_primary]
 
         if self.gti is not None:
-            hdulist.append(fits.BinTableHDU(self.gti.table, name="GTI"))
+            hdulist.append(self.gti.to_table_hdu())
 
         if self.meta_table is not None:
             hdulist.append(fits.BinTableHDU(self.meta_table, name="META_TABLE"))
@@ -1207,7 +1241,7 @@ class MapDataset(Dataset):
             kwargs["mask_fit"] = mask_fit
 
         if "GTI" in hdulist:
-            gti = GTI(Table.read(hdulist, hdu="GTI"))
+            gti = GTI.from_table_hdu(hdulist["GTI"])
             kwargs["gti"] = gti
 
         if "META_TABLE" in hdulist:
@@ -1320,7 +1354,7 @@ class MapDataset(Dataset):
         return CashCountsStatistic(self.counts, self.background)
 
     def info_dict(self, in_safe_data_range=True):
-        """Info dict with summary statistics, summed over energy
+        """Info dict with summary statistics, summed over energy.
 
         Parameters
         ----------
@@ -1497,7 +1531,7 @@ class MapDataset(Dataset):
         """Integrate the map dataset in a given region.
 
         Counts and background of the dataset are integrated in the given region,
-        taking the safe mask into accounts. The exposure is averaged in the
+        taking the safe mask into account. The exposure is averaged in the
         region again taking the safe mask into account. The PSF and energy
         dispersion kernel are taken at the center of the region.
 
@@ -1939,7 +1973,15 @@ class MapDataset(Dataset):
 
 
 class MapDatasetOnOff(MapDataset):
-    """Map dataset for on-off likelihood fitting. Uses wstat statistics.
+    """Map dataset for on-off likelihood fitting.
+
+    It bundles together the binned on and off counts, the binned IRFs as well as the on and off acceptances.
+
+    A safe mask and a fit mask can be added to exclude bins during the analysis.
+
+    It uses the Wstat statistic (see `~gammapy.stats.wstat`), therefore no background model is needed.
+
+    For more information see :ref:`datasets`.
 
     Parameters
     ----------
@@ -2139,7 +2181,7 @@ class MapDatasetOnOff(MapDataset):
         name=None,
         **kwargs,
     ):
-        """Create an empty `MapDatasetOnOff` object according to the specified geometries
+        """Create an empty `MapDatasetOnOff` object according to the specified geometries.
 
         Parameters
         ----------
@@ -2234,9 +2276,9 @@ class MapDatasetOnOff(MapDataset):
         )
 
     def to_map_dataset(self, name=None):
-        """Convert a MapDatasetOnOff to  MapDataset
+        """Convert a MapDatasetOnOff to a MapDataset.
 
-        The background model template is taken as alpha * counts_off
+        The background model template is taken as alpha * counts_off.
 
         Parameters
         ----------
@@ -2299,7 +2341,7 @@ class MapDatasetOnOff(MapDataset):
             raise TypeError("Incompatible types for MapDatasetOnOff stacking")
 
         if not self._is_stackable or not other._is_stackable:
-            raise ValueError("Cannot stack incomplete MapDatsetOnOff.")
+            raise ValueError("Cannot stack incomplete MapDatasetOnOff.")
 
         geom = self.counts.geom
         total_off = Map.from_geom(geom)
@@ -2341,8 +2383,15 @@ class MapDatasetOnOff(MapDataset):
         super().stack(other, nan_to_num=nan_to_num)
 
     def stat_sum(self):
-        """Total statistic function value given the current model parameters."""
-        return Dataset.stat_sum(self)
+        """Total statistic function value given the current model parameters.
+
+        If the off counts are passed as None and the elements of the safe mask are False, zero will be returned.
+        Otherwise, the stat sum will be calculated and returned.
+        """
+        if self.counts_off is None and not np.any(self.mask_safe.data):
+            return 0
+        else:
+            return Dataset.stat_sum(self)
 
     def fake(self, npred_background, random_state="random-seed"):
         """Simulate fake counts (on and off) for the current model and reduced IRFs.
@@ -2484,7 +2533,7 @@ class MapDatasetOnOff(MapDataset):
             kwargs["mask_fit"] = mask_fit
 
         if "GTI" in hdulist:
-            gti = GTI(Table.read(hdulist, hdu="GTI"))
+            gti = GTI.from_table_hdu(hdulist["GTI"])
             kwargs["gti"] = gti
 
         if "META_TABLE" in hdulist:
@@ -2493,7 +2542,7 @@ class MapDatasetOnOff(MapDataset):
         return cls(**kwargs)
 
     def info_dict(self, in_safe_data_range=True):
-        """Basic info dict with summary statistics
+        """Basic info dict with summary statistics.
 
         If a region is passed, then a spectrum dataset is
         extracted, and the corresponding info returned.
@@ -2654,7 +2703,7 @@ class MapDatasetOnOff(MapDataset):
         factor : int
             Downsampling factor.
         axis_name : str
-            Which non-spatial axis to downsample. By default only spatial axes are downsampled.
+            Which non-spatial axis to downsample. By default, only spatial axes are downsampled.
         name : str
             Name of the downsampled dataset.
 
