@@ -2,7 +2,7 @@
 import json
 import pytest
 import numpy as np
-from numpy.testing import assert_allclose
+from numpy.testing import assert_allclose, assert_equal
 import astropy.units as u
 from astropy.coordinates import SkyCoord
 from astropy.table import Table
@@ -18,9 +18,18 @@ from gammapy.irf import (
     EnergyDependentMultiGaussPSF,
     EnergyDispersion2D,
     PSFMap,
+    RecoPSFMap,
 )
 from gammapy.makers.utils import make_map_exposure_true_energy, make_psf_map
-from gammapy.maps import HpxGeom, Map, MapAxis, RegionGeom, WcsGeom, WcsNDMap
+from gammapy.maps import (
+    HpxGeom,
+    LabelMapAxis,
+    Map,
+    MapAxis,
+    RegionGeom,
+    WcsGeom,
+    WcsNDMap,
+)
 from gammapy.maps.io import JsonQuantityEncoder
 from gammapy.modeling import Fit
 from gammapy.modeling.models import (
@@ -956,14 +965,36 @@ def test_npred(sky_model, geom, geom_etrue):
     dataset.models = [bkg, sky_model, model1]
 
     assert_allclose(
-        dataset.npred_signal(model_name=model1.name).data.sum(), 150.7487, rtol=1e-3
+        dataset.npred_signal(model_names=[model1.name]).data.sum(), 150.7487, rtol=1e-3
     )
+    npred_model1_not_stack = dataset.npred_signal(
+        model_names=[model1.name], stack=False
+    )
+    assert isinstance(npred_model1_not_stack.geom.axes[-1], LabelMapAxis)
+    assert npred_model1_not_stack.geom.axes[-1].name == "models"
+    assert_equal(npred_model1_not_stack.geom.axes[-1].center, [model1.name])
+
     assert dataset._background_cached is None
     assert_allclose(dataset.npred_background().data.sum(), 4000.0, rtol=1e-3)
     assert_allclose(dataset._background_cached.data.sum(), 4000.0, rtol=1e-3)
 
     assert_allclose(dataset.npred().data.sum(), 9676.047906, rtol=1e-3)
     assert_allclose(dataset.npred_signal().data.sum(), 5676.04790, rtol=1e-3)
+    assert_allclose(
+        dataset.npred_signal(model_names=[model1.name, sky_model.name]).data.sum(),
+        5676.04790,
+        rtol=1e-3,
+    )
+
+    npred_all_models_not_stack = dataset.npred_signal(
+        model_names=[model1.name, sky_model.name], stack=False
+    )
+    assert_allclose(npred_all_models_not_stack.geom.data_shape, (2, 2, 100, 100))
+    assert_allclose(
+        npred_all_models_not_stack.sum_over_axes(["models"]).data.sum(),
+        5676.04790,
+        rtol=1e-3,
+    )
 
     bkg.spectral_model.norm.value = 1.1
     assert_allclose(dataset.npred_background().data.sum(), 4400.0, rtol=1e-3)
@@ -973,7 +1004,7 @@ def test_npred(sky_model, geom, geom_etrue):
         KeyError,
         match="m2",
     ):
-        dataset.npred_signal(model_name="m2")
+        dataset.npred_signal(model_names=["m2"])
 
 
 def test_stack_npred():
@@ -1873,3 +1904,8 @@ def test_peek(images):
 
     with mpl_plot_check():
         dataset.peek()
+
+
+def test_create_psf_reco(geom):
+    dat = MapDataset.create(geom, reco_psf=True)
+    assert isinstance(dat.psf, RecoPSFMap)
