@@ -1,7 +1,7 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 import pytest
 import numpy as np
-from numpy.testing import assert_allclose
+from numpy.testing import assert_allclose, assert_equal
 import astropy.units as u
 from astropy.table import Table
 from astropy.time import Time
@@ -9,7 +9,7 @@ from gammapy.data import GTI
 from gammapy.datasets import Datasets, SpectrumDataset, SpectrumDatasetOnOff
 from gammapy.irf import EDispKernelMap, EffectiveAreaTable2D
 from gammapy.makers.utils import make_map_exposure_true_energy
-from gammapy.maps import MapAxis, RegionGeom, RegionNDMap, WcsGeom
+from gammapy.maps import LabelMapAxis, MapAxis, RegionGeom, RegionNDMap, WcsGeom
 from gammapy.modeling import Fit
 from gammapy.modeling.models import (
     ConstantSpectralModel,
@@ -21,7 +21,6 @@ from gammapy.modeling.models import (
 from gammapy.utils.random import get_random_state
 from gammapy.utils.regions import compound_region_to_regions
 from gammapy.utils.testing import assert_time_allclose, mpl_plot_check, requires_data
-from gammapy.utils.time import time_ref_to_dict
 
 
 def test_data_shape(spectrum_dataset):
@@ -126,9 +125,33 @@ def test_npred_models():
     npred_sig = spectrum_dataset.npred_signal()
     assert_allclose(npred_sig.data.sum(), 64.8)
 
-    npred_sig_model1 = spectrum_dataset.npred_signal(model_name=model_1.name)
+    npred_sig_model1 = spectrum_dataset.npred_signal(model_names=[model_1.name])
     assert_allclose(npred_sig_model1.data.sum(), 32.4)
 
+    assert_allclose(
+        spectrum_dataset.npred_signal(
+            model_names=[model_1.name, model_2.name]
+        ).data.sum(),
+        64.8,
+    )
+
+    npred_model1_not_stack = spectrum_dataset.npred_signal(
+        model_names=[model_1.name], stack=False
+    )
+    assert_allclose(npred_model1_not_stack.geom.data_shape, (1, 3, 1, 1))
+    assert_allclose(npred_model1_not_stack.data.sum(), 32.4)
+    assert isinstance(npred_model1_not_stack.geom.axes[-1], LabelMapAxis)
+    assert npred_model1_not_stack.geom.axes[-1].name == "models"
+    assert_equal(npred_model1_not_stack.geom.axes[-1].center, [model_1.name])
+
+    npred_all_models_not_stack = spectrum_dataset.npred_signal(
+        model_names=[model_1.name, model_2.name], stack=False
+    )
+    assert_allclose(npred_all_models_not_stack.geom.data_shape, (2, 3, 1, 1))
+    assert_allclose(
+        npred_all_models_not_stack.sum_over_axes(["models"]).data.sum(), 64.8
+    )
+
 
 def test_npred_spatial_model(spectrum_dataset):
     model = SkyModel.create("pl", "gauss", name="test")
@@ -349,7 +372,7 @@ def test_peek(spectrum_dataset):
 class TestSpectrumOnOff:
     """Test ON OFF SpectrumDataset"""
 
-    def setup(self):
+    def setup_method(self):
         etrue = np.logspace(-1, 1, 10) * u.TeV
         self.e_true = MapAxis.from_energy_edges(etrue, name="energy_true")
         ereco = np.logspace(-1, 1, 5) * u.TeV
@@ -670,7 +693,7 @@ class TestSpectrumOnOff:
 class TestSpectralFit:
     """Test fit in astrophysical scenario"""
 
-    def setup(self):
+    def setup_method(self):
         path = "$GAMMAPY_DATA/joint-crab/spectra/hess/"
         self.datasets = Datasets(
             [
@@ -796,9 +819,7 @@ def _read_hess_obs():
 
 
 def make_gti(times, time_ref="2010-01-01"):
-    meta = time_ref_to_dict(time_ref)
-    table = Table(times, meta=meta)
-    return GTI(table)
+    return GTI.create(times["START"], times["STOP"], time_ref)
 
 
 @requires_data("gammapy-data")
@@ -835,8 +856,10 @@ def make_observation_list():
     )
 
     time_ref = Time("2010-01-01")
-    gti1 = make_gti({"START": [5, 6, 1, 2], "STOP": [8, 7, 3, 4]}, time_ref=time_ref)
-    gti2 = make_gti({"START": [14], "STOP": [15]}, time_ref=time_ref)
+    gti1 = make_gti(
+        {"START": [5, 6, 1, 2] * u.s, "STOP": [8, 7, 3, 4] * u.s}, time_ref=time_ref
+    )
+    gti2 = make_gti({"START": [14] * u.s, "STOP": [15] * u.s}, time_ref=time_ref)
 
     exposure = aeff * livetime
     exposure.meta["livetime"] = livetime
@@ -870,7 +893,7 @@ def make_observation_list():
 
 @requires_data("gammapy-data")
 class TestSpectrumDatasetOnOffStack:
-    def setup(self):
+    def setup_method(self):
         self.datasets = _read_hess_obs()
         # Change threshold to make stuff more interesting
 
@@ -945,10 +968,9 @@ class TestSpectrumDatasetOnOffStack:
     def test_stack_gti(self):
         obs1, obs2 = make_observation_list()
         obs1.stack(obs2)
-        table_gti = Table({"START": [1.0, 5.0, 14.0], "STOP": [4.0, 8.0, 15.0]})
-        table_gti_stacked_obs = obs1.gti.table
-        assert_allclose(table_gti_stacked_obs["START"], table_gti["START"])
-        assert_allclose(table_gti_stacked_obs["STOP"], table_gti["STOP"])
+
+        assert_allclose(obs1.gti.met_start.value, [1.0, 5.0, 14.0])
+        assert_allclose(obs1.gti.met_stop.value, [4.0, 8.0, 15.0])
 
 
 @requires_data("gammapy-data")
@@ -1040,7 +1062,7 @@ def test_spectrum_dataset_on_off_to_yaml(tmpdir):
 class TestFit:
     """Test fit on counts spectra without any IRFs"""
 
-    def setup(self):
+    def setup_method(self):
         self.nbins = 30
         energy = np.logspace(-1, 1, self.nbins + 1) * u.TeV
         self.source_model = SkyModel(
@@ -1155,3 +1177,17 @@ class TestFit:
         profile = fit.stat_profile(datasets=[dataset], parameter="index")
         actual = values[np.argmin(profile["stat_scan"])]
         assert_allclose(actual, true_idx, rtol=0.01)
+
+
+def test_stat_sum():
+    axis = MapAxis.from_energy_bounds(0.1, 10, 5, unit="TeV")
+    geom = RegionGeom.create(None, axes=[axis])
+    dataset = SpectrumDatasetOnOff.create(geom)
+    dataset.counts_off = None
+
+    stat = dataset.stat_sum()
+    assert stat == 0
+
+    dataset.mask_safe.data[0] = True
+    with pytest.raises(AttributeError):
+        dataset.stat_sum()
