@@ -9,7 +9,7 @@ from astropy.time import Time
 from astropy.visualization import quantity_support
 import matplotlib.pyplot as plt
 from gammapy.maps import MapAxis, Maps, RegionNDMap, TimeMapAxis
-from gammapy.maps.axes import flat_if_equal
+from gammapy.maps.axes import flat_if_equal, UNIT_STRING_FORMAT
 from gammapy.modeling.models import TemplateSpectralModel
 from gammapy.modeling.models.spectral import scale_plot_flux
 from gammapy.modeling.scipy import stat_profile_ul_scipy
@@ -471,7 +471,7 @@ class FluxPoints(FluxMaps):
 
         return y_errn, y_errp
 
-    def plot(self, ax=None, sed_type=None, energy_power=0, **kwargs):
+    def plot(self, ax=None, sed_type=None, energy_power=0, time_format="iso", **kwargs):
         """Plot flux points.
 
         Parameters
@@ -482,6 +482,8 @@ class FluxPoints(FluxMaps):
             Sed type
         energy_power : float
             Power of energy to multiply flux axis with
+        time_format : {"iso", "mjd"}
+            Used time format is a time axis is present. Default: "iso"
         **kwargs : dict
             Keyword arguments passed to `~RegionNDMap.plot`
 
@@ -529,8 +531,10 @@ class FluxPoints(FluxMaps):
             kwargs.setdefault("yerr", None)
 
         flux = scale_plot_flux(flux=flux.to_unit(flux_unit), energy_power=energy_power)
+        if "time" in flux.geom.axes_names:
+            flux.geom.axes["time"].time_format = time_format
         ax = flux.plot(ax=ax, **kwargs)
-        ax.set_ylabel(f"{sed_type} [{ax.yaxis.units}]")
+        ax.set_ylabel(f"{sed_type} [{ax.yaxis.units.to_string(UNIT_STRING_FORMAT)}]")
         ax.set_yscale("log")
         return ax
 
@@ -622,7 +626,7 @@ class FluxPoints(FluxMaps):
 
         axis.format_plot_xaxis(ax=ax)
 
-        ax.set_ylabel(f"{sed_type} [{ax.yaxis.units}]")
+        ax.set_ylabel(f"{sed_type} [{ax.yaxis.units.to_string(UNIT_STRING_FORMAT)}]")
         ax.set_yscale("log")
 
         if add_cbar:
