@@ -1,4 +1,5 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
+import logging
 import numpy as np
 from astropy.table import Column, Table
 from gammapy.maps import Map
@@ -10,7 +11,7 @@ __all__ = ["SensitivityEstimator"]
 
 
 class SensitivityEstimator(Estimator):
-    """Estimate differential sensitivity.
+    """Estimate sensitivity.
 
     This class allows to determine for each reconstructed energy bin the flux
     associated to the number of gamma-ray events for which the significance is
@@ -38,7 +39,11 @@ class SensitivityEstimator(Estimator):
     tag = "SensitivityEstimator"
 
     def __init__(
-        self, spectrum=None, n_sigma=5.0, gamma_min=10, bkg_syst_fraction=0.05
+        self,
+        spectrum=None,
+        n_sigma=5.0,
+        gamma_min=10,
+        bkg_syst_fraction=0.05,
     ):
 
         if spectrum is None:
@@ -135,6 +140,9 @@ class SensitivityEstimator(Estimator):
         criterion = self._get_criterion(
             excess.data.squeeze(), dataset.background.data.squeeze()
         )
+        logging.warning(
+            "Table column name energy will be deprecated by e_ref since v1.2"
+        )
 
         return Table(
             [
@@ -144,6 +152,24 @@ class SensitivityEstimator(Estimator):
                     format="5g",
                     description="Reconstructed Energy",
                 ),
+                Column(
+                    data=energy,
+                    name="e_ref",
+                    format="5g",
+                    description="Energy center",
+                ),
+                Column(
+                    data=dataset._geom.axes["energy"].edges_min,
+                    name="e_min",
+                    format="5g",
+                    description="Energy edge low",
+                ),
+                Column(
+                    data=dataset._geom.axes["energy"].edges_max,
+                    name="e_max",
+                    format="5g",
+                    description="Energy edge high",
+                ),
                 Column(
                     data=e2dnde,
                     name="e2dnde",
@@ -151,19 +177,19 @@ class SensitivityEstimator(Estimator):
                     description="Energy squared times differential flux",
                 ),
                 Column(
-                    data=excess.data.squeeze(),
+                    data=np.atleast_1d(excess.data.squeeze()),
                     name="excess",
                     format="5g",
                     description="Number of excess counts in the bin",
                 ),
                 Column(
-                    data=dataset.background.data.squeeze(),
+                    data=np.atleast_1d(dataset.background.data.squeeze()),
                     name="background",
                     format="5g",
                     description="Number of background counts in the bin",
                 ),
                 Column(
-                    data=criterion,
+                    data=np.atleast_1d(criterion),
                     name="criterion",
                     description="Sensitivity-limiting criterion",
                 ),
