@@ -4,6 +4,7 @@ import astropy.units as u
 from astropy.visualization import quantity_support
 import matplotlib.pyplot as plt
 from gammapy.maps import MapAxes, MapAxis
+from gammapy.maps.axes import UNIT_STRING_FORMAT
 from .core import IRF
 
 __all__ = ["EffectiveAreaTable2D"]
@@ -101,7 +102,9 @@ class EffectiveAreaTable2D(IRF):
                 ax.plot(energy_axis.center, area, label=label, **kwargs)
 
         energy_axis.format_plot_xaxis(ax=ax)
-        ax.set_ylabel(f"Effective Area [{ax.yaxis.units}]")
+        ax.set_ylabel(
+            f"Effective Area [{ax.yaxis.units.to_string(UNIT_STRING_FORMAT)}]"
+        )
         ax.legend()
         return ax
 
@@ -170,7 +173,7 @@ class EffectiveAreaTable2D(IRF):
         offset.format_plot_yaxis(ax=ax)
 
         if add_cbar:
-            label = f"Effective Area [{aeff.unit}]"
+            label = f"Effective Area [{aeff.unit.to_string(UNIT_STRING_FORMAT)}]"
             ax.figure.colorbar(caxes, ax=ax, label=label)
 
         return ax
@@ -184,10 +187,12 @@ class EffectiveAreaTable2D(IRF):
             Size of the figure.
 
         """
-        fig, axes = plt.subplots(nrows=1, ncols=3, figsize=figsize)
-        self.plot(ax=axes[2])
+        ncols = 2 if self.is_pointlike else 3
+        fig, axes = plt.subplots(nrows=1, ncols=ncols, figsize=figsize)
+        self.plot(ax=axes[ncols - 1])
         self.plot_energy_dependence(ax=axes[0])
-        self.plot_offset_dependence(ax=axes[1])
+        if self.is_pointlike is False:
+            self.plot_offset_dependence(ax=axes[1])
         plt.tight_layout()
 
     @classmethod
@@ -199,7 +204,7 @@ class EffectiveAreaTable2D(IRF):
         https://ui.adsabs.harvard.edu/abs/2010MNRAS.402.1342A .
 
         .. math::
-            A_{eff}(E) = g_1 \left(\frac{E}{\mathrm{MeV}}\right)^{-g_2}\exp{\left(-\frac{g_3}{E}\right)}  # noqa: E501
+            A_{eff}(E) = g_1 \left(\frac{E}{\mathrm{MeV}}\right)^{-g_2}\exp{\left(-\frac{g_3}{E}\right)}
 
         This method does not model the offset dependence of the effective area,
         but just assumes that it is constant.
@@ -215,7 +220,7 @@ class EffectiveAreaTable2D(IRF):
         -------
         aeff : `EffectiveAreaTable2D`
             Effective area table
-        """
+        """  # noqa: E501
         # Put the parameters g in a dictionary.
         # Units: g1 (cm^2), g2 (), g3 (MeV)
         pars = {
