@@ -1,8 +1,10 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 import numpy as np
 from gammapy.data import EventList
-from gammapy.datasets import SpectrumDatasetOnOff
-from gammapy.maps import RegionNDMap
+from gammapy.datasets import MapDatasetOnOff, SpectrumDataset
+from gammapy.maps import Map
+from gammapy.makers.utils import make_counts_rad_max
+from regions import PointSkyRegion
 from ..core import Maker
 
 __all__ = ["PhaseBackgroundMaker"]
@@ -13,42 +15,47 @@ class PhaseBackgroundMaker(Maker):
 
     TODO: For a usage example see future notebook.
 
-    TODO: The phase interval has to be between 0 and 1.
-    Cases like [-0.1, 0.1], for example, are still not supported.
-
     Parameters
     ----------
     on_phase : `tuple` or list of tuples
-        on-phase defined by the two edges of each interval (edges are excluded)
+        on-phase defined by the two edges of each interval (edges are excluded).
     off_phase : `tuple` or list of tuples
-        off-phase defined by the two edges of each interval (edges are excluded)
+        off-phase defined by the two edges of each interval (edges are excluded).
+    phase_column_name : `str`
+        The name of the column in the event file from which the phase informations are extracted. Default is 'PHASE'.
     """
 
     tag = "PhaseBackgroundMaker"
 
-    def __init__(self, on_phase, off_phase):
+    def __init__(self, on_phase, off_phase, phase_column_name="PHASE"):
         self.on_phase = self._check_intervals(on_phase)
         self.off_phase = self._check_intervals(off_phase)
+        self.phase_column_name = phase_column_name
 
     def __str__(self):
         s = self.__class__.__name__
-        s += f"\n{self.on_phase}"
-        s += f"\n{self.off_phase}"
+        s += f"\nOn phase interval : {self.on_phase}"
+        s += f"\nOff phase interval : {self.off_phase}"
+        s += f"\nPhase column name : {self.phase_column_name}"
         return s
 
     @staticmethod
-    def _make_counts(dataset, observation, phases):
+    def _make_counts(dataset, observation, phases, phase_column_name):
 
         event_lists = []
         for interval in phases:
             events = observation.events.select_parameter(
-                parameter="PHASE", band=interval
+                parameter=phase_column_name, band=interval
             )
             event_lists.append(events)
 
         events = EventList.from_stack(event_lists)
-        counts = RegionNDMap.from_geom(dataset.counts.geom)
-        counts.fill_events(events)
+        geom = dataset.counts.geom
+        if geom.is_region and isinstance(geom.region, PointSkyRegion):
+            counts = make_counts_rad_max(geom, observation.rad_max, events)
+        else:
+            counts = Map.from_geom(geom)
+            counts.fill_events(events)
         return counts
 
     def make_counts_off(self, dataset, observation):
@@ -66,10 +73,12 @@ class PhaseBackgroundMaker(Maker):
         counts_off : `RegionNDMap`
             Off counts.
         """
-        return self._make_counts(dataset, observation, self.off_phase)
+        return self._make_counts(
+            dataset, observation, self.off_phase, self.phase_column_name
+        )
 
     def make_counts(self, dataset, observation):
-        """Make off counts.
+        """Make on counts.
 
         Parameters
         ----------
@@ -80,10 +89,12 @@ class PhaseBackgroundMaker(Maker):
 
         Returns
         -------
-        counts_off : `RegionNDMap`
-            Off counts.
+        counts : `RegionNDMap`
+            On counts.
         """
-        return self._make_counts(dataset, observation, self.on_phase)
+        return self._make_counts(
+            dataset, observation, self.on_phase, self.phase_column_name
+        )
 
     def run(self, dataset, observation):
         """Run all steps.
@@ -103,30 +114,34 @@ class PhaseBackgroundMaker(Maker):
         counts_off = self.make_counts_off(dataset, observation)
         counts = self.make_counts(dataset, observation)
 
-        acceptance = RegionNDMap.from_geom(geom=dataset.counts.geom)
+        acceptance = Map.from_geom(geom=dataset.counts.geom)
         acceptance.data = np.sum([_[1] - _[0] for _ in self.on_phase])
 
-        acceptance_off = RegionNDMap.from_geom(geom=dataset.counts.geom)
+        acceptance_off = Map.from_geom(geom=dataset.counts.geom)
         acceptance_off.data = np.sum([_[1] - _[0] for _ in self.off_phase])
 
-        dataset_on_off = SpectrumDatasetOnOff.from_spectrum_dataset(
+        dataset_on_off = MapDatasetOnOff.from_map_dataset(
             dataset=dataset,
             counts_off=counts_off,
             acceptance=acceptance,
             acceptance_off=acceptance_off,
         )
         dataset_on_off.counts = counts
+
+        if isinstance(dataset, SpectrumDataset):
+            dataset_on_off = dataset_on_off.to_spectrum_dataset(dataset._geom.region)
+
         return dataset_on_off
 
     @staticmethod
     def _check_intervals(intervals):
-        """Split phase intervals that go beyond phase 1"""
+        """Split phase intervals that go below phase 0 and above phase 1"""
         if isinstance(intervals, tuple):
             intervals = [intervals]
 
         for phase_interval in intervals:
-            if phase_interval[0] > phase_interval[1]:
+            if phase_interval[0] % 1 > phase_interval[1] % 1:
                 intervals.remove(phase_interval)
-                intervals.append([phase_interval[0], 1])
-                intervals.append([0, phase_interval[1]])
+                intervals.append([phase_interval[0] % 1, 1])
+                intervals.append([0, phase_interval[1] % 1])
         return intervals
