@@ -3,7 +3,6 @@ import logging
 import astropy.units as u
 from astropy.table import Table
 from regions import PointSkyRegion
-from gammapy.data.pointing import PointingMode
 from gammapy.irf import EDispKernelMap, PSFMap, RecoPSFMap
 from gammapy.maps import Map
 from .core import Maker
@@ -172,7 +171,7 @@ class MapDatasetMaker(Maker):
                 geom=geom,
             )
         return make_map_exposure_true_energy(
-            pointing=observation.pointing_radec,
+            pointing=observation.get_pointing_icrs(observation.tmid),
             livetime=observation.observation_live_time_duration,
             aeff=observation.aeff,
             geom=geom,
@@ -196,7 +195,7 @@ class MapDatasetMaker(Maker):
             Exposure map.
         """
         return make_map_exposure_true_energy(
-            pointing=observation.pointing_radec,
+            pointing=observation.get_pointing_icrs(observation.tmid),
             livetime=observation.observation_live_time_duration,
             aeff=observation.aeff,
             geom=geom,
@@ -233,12 +232,13 @@ class MapDatasetMaker(Maker):
             bkg = bkg.pad(1, mode="edge", axis_name="offset")
 
         return make_map_background_irf(
-            pointing=observation.fixed_pointing_info,
+            pointing=observation.pointing,
             ontime=observation.observation_time_duration,
             bkg=bkg,
             geom=geom,
             oversampling=self.background_oversampling,
             use_region_center=use_region_center,
+            obstime=observation.tmid,
         )
 
     def make_edisp(self, geom, observation):
@@ -262,7 +262,7 @@ class MapDatasetMaker(Maker):
 
         return make_edisp_map(
             edisp=observation.edisp,
-            pointing=observation.pointing_radec,
+            pointing=observation.get_pointing_icrs(observation.tmid),
             geom=geom,
             exposure_map=exposure,
             use_region_center=use_region_center,
@@ -294,7 +294,7 @@ class MapDatasetMaker(Maker):
 
         return make_edisp_kernel_map(
             edisp=observation.edisp,
-            pointing=observation.pointing_radec,
+            pointing=observation.get_pointing_icrs(observation.tmid),
             geom=geom,
             exposure_map=exposure,
             use_region_center=use_region_center,
@@ -325,7 +325,7 @@ class MapDatasetMaker(Maker):
 
         return make_psf_map(
             psf=psf,
-            pointing=observation.pointing_radec,
+            pointing=observation.get_pointing_icrs(observation.tmid),
             geom=geom,
             exposure_map=exposure,
         )
@@ -343,22 +343,20 @@ class MapDatasetMaker(Maker):
         -------
         meta_table: `~astropy.table.Table`
         """
-        meta_table = Table()
-        meta_table["TELESCOP"] = [observation.aeff.meta.get("TELESCOP", "Unknown")]
-        meta_table["OBS_ID"] = [observation.obs_id]
 
-        if observation.fixed_pointing_info.mode == PointingMode.POINTING:
-            meta_table["OBS_MODE"] = "POINTING"
-            meta_table["RA_PNT"] = [observation.pointing_radec.icrs.ra.deg] * u.deg
-            meta_table["DEC_PNT"] = [observation.pointing_radec.icrs.dec.deg] * u.deg
-        elif observation.fixed_pointing_info.mode == PointingMode.DRIFT:
-            meta_table["OBS_MODE"] = "DRIFT"
-            meta_table["ALT_PNT"] = [
-                observation.fixed_pointing_info.fixed_altaz.alt.deg
-            ] * u.deg
-            meta_table["AZ_PNT"] = [
-                observation.fixed_pointing_info.fixed_altaz.az.deg
-            ] * u.deg
+        row = {}
+        row["TELESCOP"] = observation.aeff.meta.get("TELESCOP", "Unknown")
+        row["OBS_ID"] = observation.obs_id
+
+        row.update(observation.pointing.to_fits_header())
+
+        meta_table = Table([row])
+        if "ALT_PNT" in meta_table.colnames:
+            meta_table["ALT_PNT"].unit = u.deg
+            meta_table["AZ_PNT"].unit = u.deg
+        if "RA_PNT" in meta_table.colnames:
+            meta_table["RA_PNT"].unit = u.deg
+            meta_table["DEC_PNT"].unit = u.deg
 
         return meta_table
 
