@@ -41,9 +41,8 @@ def dataset(observation_cta_1dc):
     axis_true = MapAxis.from_bounds(
         0.1, 50, nbin=30, unit="TeV", name="energy_true", interp="log"
     )
-    geom = WcsGeom.create(
-        npix=(11, 11), axes=[axis], skydir=observation_cta_1dc.pointing_radec
-    )
+    pointing = observation_cta_1dc.get_pointing_icrs(observation_cta_1dc.tmid)
+    geom = WcsGeom.create(npix=(11, 11), axes=[axis], skydir=pointing)
 
     empty_dataset = MapDataset.create(geom=geom, energy_axis_true=axis_true)
     dataset_maker = MapDatasetMaker()
@@ -56,7 +55,8 @@ def shifted_dataset(observation_cta_1dc):
     axis_true = MapAxis.from_bounds(
         0.1, 2, nbin=10, unit="TeV", name="energy_true", interp="log"
     )
-    skydir = observation_cta_1dc.pointing_radec.directional_offset_by(
+    pointing = observation_cta_1dc.get_pointing_icrs(observation_cta_1dc.tmid)
+    skydir = pointing.directional_offset_by(
         position_angle=0.0 * u.deg, separation=10 * u.deg
     )
     geom = WcsGeom.create(npix=(11, 11), axes=[axis], skydir=skydir)
@@ -78,7 +78,8 @@ def spectrum_dataset_on_off(observation_cta_1dc):
     )
     axis_migra = MapAxis.from_bounds(0.2, 5.0, nbin=48, name="migra")
 
-    region = CircleSkyRegion(observation_cta_1dc.pointing_radec, radius=0.3 * u.deg)
+    pointing = observation_cta_1dc.get_pointing_icrs(observation_cta_1dc.tmid)
+    region = CircleSkyRegion(pointing, radius=0.3 * u.deg)
     geom = RegionGeom.create(region, axes=[axis])
 
     return SpectrumDatasetOnOff.create(
@@ -88,8 +89,10 @@ def spectrum_dataset_on_off(observation_cta_1dc):
 
 @requires_data()
 def test_safe_mask_maker_offset_max(dataset, observation_cta_1dc):
+    pointing = observation_cta_1dc.get_pointing_icrs(observation_cta_1dc.tmid)
     safe_mask_maker = SafeMaskMaker(
-        offset_max="3 deg", position=observation_cta_1dc.pointing_radec
+        offset_max="3 deg",
+        position=pointing,
     )
 
     mask_offset = safe_mask_maker.make_mask_offset_max(
@@ -100,7 +103,8 @@ def test_safe_mask_maker_offset_max(dataset, observation_cta_1dc):
 
 @requires_data()
 def test_safe_mask_maker_aeff_default(dataset, observation_cta_1dc, caplog):
-    safe_mask_maker = SafeMaskMaker(position=observation_cta_1dc.pointing_radec)
+    pointing = observation_cta_1dc.get_pointing_icrs(observation_cta_1dc.tmid)
+    safe_mask_maker = SafeMaskMaker(position=pointing)
 
     mask_energy_aeff_default = safe_mask_maker.make_mask_energy_aeff_default(
         dataset=dataset, observation=observation_cta_1dc
@@ -119,7 +123,8 @@ def test_safe_mask_maker_aeff_default(dataset, observation_cta_1dc, caplog):
 
 @requires_data()
 def test_safe_mask_maker_aeff_max(dataset, observation_cta_1dc):
-    safe_mask_maker = SafeMaskMaker(position=observation_cta_1dc.pointing_radec)
+    pointing = observation_cta_1dc.get_pointing_icrs(observation_cta_1dc.tmid)
+    safe_mask_maker = SafeMaskMaker(position=pointing)
 
     mask_aeff_max = safe_mask_maker.make_mask_energy_aeff_max(dataset)
 
@@ -180,9 +185,8 @@ def test_safe_mask_maker_offset_max_fixed_offset(dataset, observation_cta_1dc):
 
 @requires_data()
 def test_safe_mask_maker_edisp_bias(dataset, observation_cta_1dc):
-    safe_mask_maker = SafeMaskMaker(
-        bias_percent=0.02, position=observation_cta_1dc.pointing_radec
-    )
+    pointing = observation_cta_1dc.get_pointing_icrs(observation_cta_1dc.tmid)
+    safe_mask_maker = SafeMaskMaker(bias_percent=0.02, position=pointing)
 
     mask_edisp_bias = safe_mask_maker.make_mask_energy_edisp_bias(dataset=dataset)
     assert_allclose(mask_edisp_bias.data.sum(), 1815)
@@ -214,7 +218,8 @@ def test_safe_mask_maker_edisp_bias_fixed_offset(dataset, observation_cta_1dc):
 
 @requires_data()
 def test_safe_mask_maker_bkg_peak(dataset, observation_cta_1dc):
-    safe_mask_maker = SafeMaskMaker(position=observation_cta_1dc.pointing_radec)
+    pointing = observation_cta_1dc.get_pointing_icrs(observation_cta_1dc.tmid)
+    safe_mask_maker = SafeMaskMaker(position=pointing)
 
     mask_bkg_peak = safe_mask_maker.make_mask_energy_bkg_peak(dataset)
     assert_allclose(mask_bkg_peak.data.sum(), 1936)
@@ -222,15 +227,14 @@ def test_safe_mask_maker_bkg_peak(dataset, observation_cta_1dc):
 
 @requires_data()
 def test_safe_mask_maker_bkg_peak_first_bin(dataset, observation_cta_1dc):
-    safe_mask_maker = SafeMaskMaker(position=observation_cta_1dc.pointing_radec)
+    pointing = observation_cta_1dc.get_pointing_icrs(observation_cta_1dc.tmid)
+    safe_mask_maker = SafeMaskMaker(position=pointing)
 
     dataset_maker = MapDatasetMaker()
 
     axis = MapAxis.from_bounds(1.0, 10, nbin=6, unit="TeV", name="energy", interp="log")
 
-    geom = WcsGeom.create(
-        npix=(5, 5), axes=[axis], skydir=observation_cta_1dc.pointing_radec
-    )
+    geom = WcsGeom.create(npix=(5, 5), axes=[axis], skydir=pointing)
     empty_dataset = MapDataset.create(geom=geom)
     dataset = dataset_maker.run(empty_dataset, observation_cta_1dc)
     mask_bkg_peak = safe_mask_maker.make_mask_energy_bkg_peak(dataset)
@@ -238,7 +242,7 @@ def test_safe_mask_maker_bkg_peak_first_bin(dataset, observation_cta_1dc):
 
 
 @requires_data()
-def test_safe_mask_maker_no_root(dataset, observation_cta_1dc):
+def test_safe_mask_maker_no_root(dataset):
     safe_mask_maker_noroot = SafeMaskMaker(
         offset_max="3 deg", aeff_percent=-10, bias_percent=-10
     )
@@ -251,6 +255,7 @@ def test_safe_mask_maker_no_root(dataset, observation_cta_1dc):
 @requires_data()
 def test_safe_mask_maker_bkg_invalid(observations_hess_dl3):
     obs = observations_hess_dl3[0]
+    pointing = obs.get_pointing_icrs(obs.tmid)
 
     axis = MapAxis.from_bounds(
         0.1, 10, nbin=16, unit="TeV", name="energy", interp="log"
@@ -258,7 +263,7 @@ def test_safe_mask_maker_bkg_invalid(observations_hess_dl3):
     axis_true = MapAxis.from_bounds(
         0.1, 50, nbin=30, unit="TeV", name="energy_true", interp="log"
     )
-    geom = WcsGeom.create(npix=(9, 9), axes=[axis], skydir=obs.pointing_radec)
+    geom = WcsGeom.create(npix=(9, 9), axes=[axis], skydir=pointing)
 
     empty_dataset = MapDataset.create(geom=geom, energy_axis_true=axis_true)
     dataset_maker = MapDatasetMaker()
