@@ -16,6 +16,7 @@ from gammapy.maps import (
     RegionNDMap,
     TimeMapAxis,
 )
+from gammapy.utils.deprecation import GammapyDeprecationWarning
 from gammapy.utils.testing import mpl_plot_check, requires_data
 
 
@@ -58,19 +59,6 @@ def point_region_map():
     return m
 
 
-@pytest.fixture
-def region_map_true():
-    axis = MapAxis.from_energy_bounds("1 TeV", "10 TeV", nbin=6, name="energy_true")
-    m = Map.create(
-        region="icrs;circle(83.63, 21.51, 1)",
-        map_type="region",
-        axes=[axis],
-        unit="1/TeV",
-    )
-    m.data = np.arange(m.data.size, dtype=float).reshape(m.geom.data_shape)
-    return m
-
-
 def test_region_nd_map(region_map):
     assert_allclose(region_map.data.sum(), 15)
     assert region_map.geom.frame == "icrs"
@@ -102,7 +90,8 @@ def test_region_nd_map_plot(region_map):
     with mpl_plot_check():
         region_map.plot()
 
-    ax = plt.subplot(projection=region_map.geom.wcs)
+    fig = plt.figure()
+    ax = fig.add_subplot(1, 1, 1, projection=region_map.geom.wcs)
     with mpl_plot_check():
         region_map.plot_region(ax=ax)
 
@@ -256,7 +245,12 @@ def test_region_nd_map_fill_events(region_map):
     region_map = Map.from_geom(region_map.geom)
     region_map.fill_events(events)
 
+    weights = np.linspace(0, 1, len(events.time))
+    region_map2 = Map.from_geom(region_map.geom)
+    region_map2.fill_events(events, weights=weights)
+
     assert_allclose(region_map.data.sum(), 665)
+    assert_allclose(region_map2.data.sum(), 328.33487)
 
 
 @requires_data()
@@ -268,22 +262,22 @@ def test_region_nd_map_fill_events_point_sky_region(point_region_map):
 
     assert_allclose(region_map.data.sum(), 0)
 
+    weights = np.linspace(0, 1, len(events.time))
+    region_map = Map.from_geom(point_region_map.geom)
+    region_map.fill_events(events, weights=weights)
+    assert_allclose(region_map.data.sum(), 0)
 
-def test_apply_edisp(region_map_true):
-    e_true = region_map_true.geom.axes[0]
-    e_reco = MapAxis.from_energy_bounds("1 TeV", "10 TeV", nbin=3)
+
+def test_apply_edisp(point_region_map):
+    e_true = MapAxis.from_energy_bounds("1 TeV", "10 TeV", nbin=3, name="energy_true")
+    e_reco = point_region_map.geom.axes[0]
 
     edisp = EDispKernel.from_diagonal_response(
         energy_axis_true=e_true, energy_axis=e_reco
     )
 
-    m = region_map_true.apply_edisp(edisp)
-    assert m.geom.data_shape == (3, 1, 1)
-
-    e_reco = m.geom.axes[0].edges
-    assert e_reco.unit == "TeV"
-    assert m.geom.axes[0].name == "energy"
-    assert_allclose(e_reco[[0, -1]].value, [1, 10])
+    with pytest.raises(GammapyDeprecationWarning):
+        point_region_map.apply_edisp(edisp)
 
 
 def test_region_nd_map_resample_axis():
