@@ -2,8 +2,9 @@
 import itertools
 import logging
 import numpy as np
+from astropy.table import Table
+from gammapy.utils.deprecation import deprecated
 from gammapy.utils.pbar import progress_bar
-from gammapy.utils.table import table_from_row_data
 from .covariance import Covariance
 from .iminuit import (
     confidence_iminuit,
@@ -137,6 +138,10 @@ class Fit:
         self._minuit = None
 
     @property
+    @deprecated(
+        "v1.1",
+        message="The IMinuit object is attached to the OptimizeResult object instead.",
+    )
     def minuit(self):
         """Iminuit object"""
         return self._minuit
@@ -167,7 +172,9 @@ class Fit:
             log.warning("No covariance estimate - not supported by this backend.")
             return FitResult(optimize_result=optimize_result)
 
-        covariance_result = self.covariance(datasets=datasets)
+        covariance_result = self.covariance(
+            datasets=datasets, optimize_result=optimize_result
+        )
 
         optimize_result.models.covariance = Covariance(
             optimize_result.models.parameters, covariance_result.matrix
@@ -217,7 +224,7 @@ class Fit:
             self._minuit = optimizer
             kwargs["method"] = "migrad"
 
-        trace = table_from_row_data(info.pop("trace"))
+        trace = Table(info.pop("trace"))
 
         if self.store_trace:
             idx = [
@@ -237,10 +244,11 @@ class Fit:
             backend=backend,
             method=kwargs.get("method", backend),
             trace=trace,
+            minuit=optimizer,
             **info,
         )
 
-    def covariance(self, datasets):
+    def covariance(self, datasets, optimize_result=None):
         """Estimate the covariance matrix.
 
         Assumes that the model parameters are already optimised.
@@ -249,6 +257,9 @@ class Fit:
         ----------
         datasets : `Datasets` or list of `Dataset`
             Datasets to optimize.
+        optimize_result : `OptimizeResult`
+            Optimization result. Can be optionally used to pass the state of the IMinuit object
+            to the covariance estimation. This might save computation time in certain cases.
 
         Returns
         -------
@@ -259,7 +270,10 @@ class Fit:
         parameters = datasets.models.parameters
 
         kwargs = self.covariance_opts.copy()
-        kwargs["minuit"] = self.minuit
+
+        if optimize_result is not None and optimize_result.backend == "minuit":
+            kwargs["minuit"] = optimize_result.minuit
+
         backend = kwargs.pop("backend", self.backend)
         compute = registry.get("covariance", backend)
 
@@ -278,13 +292,16 @@ class Fit:
             )
             datasets.models.covariance = matrix
 
+        if optimize_result:
+            optimize_result.models.covariance = matrix.data.copy()
+
         # TODO: decide what to return, and fill the info correctly!
         return CovarianceResult(
             backend=backend,
             method=method,
             success=info["success"],
             message=info["message"],
-            matrix=matrix.data.copy(),
+            matrix=optimize_result.models.covariance.data,
         )
 
     def confidence(self, datasets, parameter, sigma=1, reoptimize=True):
@@ -565,13 +582,19 @@ class CovarianceResult(FitStepResult):
 class OptimizeResult(FitStepResult):
     """Optimize result object."""
 
-    def __init__(self, models, nfev, total_stat, trace, **kwargs):
+    def __init__(self, models, nfev, total_stat, trace, minuit=None, **kwargs):
         self._models = models
         self._nfev = nfev
         self._total_stat = total_stat
         self._trace = trace
+        self._minuit = minuit
         super().__init__(**kwargs)
 
+    @property
+    def minuit(self):
+        """Minuit object"""
+        return self._minuit
+
     @property
     def parameters(self):
         """Best fit parameters"""
@@ -617,12 +640,13 @@ class FitResult:
 
     def __init__(self, optimize_result=None, covariance_result=None):
         self._optimize_result = optimize_result
-
-        if covariance_result:
-            self.optimize_result.models.covariance = covariance_result.matrix
-
         self._covariance_result = covariance_result
 
+    @property
+    def minuit(self):
+        """Minuit object"""
+        return self.optimize_result.minuit
+
     # TODO: is the convenience access needed?
     @property
     def parameters(self):
