@@ -15,6 +15,7 @@ from .spatial import (
     GaussianSpatialModel,
     GeneralizedGaussianSpatialModel,
     PointSpatialModel,
+    PiecewiseNormSpatialModel,
     Shell2SpatialModel,
     ShellSpatialModel,
     SpatialModel,
@@ -97,6 +98,7 @@ __all__ = [
     "MODEL_REGISTRY",
     "NaimaSpectralModel",
     "PiecewiseNormSpectralModel",
+    "PiecewiseNormSpatialModel",
     "PointSpatialModel",
     "PowerLaw2SpectralModel",
     "PowerLawNormSpectralModel",
@@ -133,6 +135,7 @@ SPATIAL_MODEL_REGISTRY = Registry(
         DiskSpatialModel,
         GaussianSpatialModel,
         GeneralizedGaussianSpatialModel,
+        PiecewiseNormSpatialModel,
         PointSpatialModel,
         ShellSpatialModel,
         Shell2SpatialModel,
