@@ -11,7 +11,6 @@ import matplotlib.pyplot as plt
 import yaml
 from gammapy.maps import Map, RegionGeom
 from gammapy.modeling import Covariance, Parameter, Parameters
-from gammapy.modeling.covariance import copy_covariance
 from gammapy.utils.scripts import make_name, make_path
 
 __all__ = ["Model", "Models", "DatasetModels", "ModelBase"]
@@ -95,6 +94,11 @@ class ModelBase:
 
         self._covariance = Covariance(self.parameters)
 
+        covariance_data = kwargs.get("covariance_data", None)
+
+        if covariance_data is not None:
+            self.covariance = covariance_data
+
     def __getattribute__(self, name):
         value = object.__getattribute__(self, name)
 
@@ -163,7 +167,6 @@ class ModelBase:
             [getattr(self, name) for name in self.default_parameters.names]
         )
 
-    @copy_covariance
     def copy(self, **kwargs):
         """A deep copy."""
         return copy.deepcopy(self)
@@ -226,6 +229,9 @@ class ModelBase:
         #  `SpatialModel` base class
         if "frame" in data:
             kwargs["frame"] = data["frame"]
+        # TODO: same as above for temporal models
+        if "scale" in data:
+            kwargs["scale"] = data["scale"]
 
         return cls.from_parameters(parameters, **kwargs)
 
@@ -326,9 +332,11 @@ class DatasetModels(collections.abc.Sequence):
     ----------
     models : `SkyModel`, list of `SkyModel` or `Models`
         Sky models
+    covariance_data : `~numpy.ndarray`
+        Covariance data
     """
 
-    def __init__(self, models=None):
+    def __init__(self, models=None, covariance_data=None):
         if models is None:
             models = []
 
@@ -340,6 +348,7 @@ class DatasetModels(collections.abc.Sequence):
             raise TypeError(f"Invalid type: {models!r}")
 
         unique_names = []
+
         for model in models:
             if model.name in unique_names:
                 raise (ValueError("Model names must be unique"))
@@ -347,8 +356,13 @@ class DatasetModels(collections.abc.Sequence):
 
         self._models = models
         self._covar_file = None
+
         self._covariance = Covariance(self.parameters)
 
+        # Set separataly because this trigggers the update mechanism on the sub-models
+        if covariance_data is not None:
+            self.covariance = covariance_data
+
     def _check_covariance(self):
         if not self.parameters == self._covariance.parameters:
             self._covariance = Covariance.from_stack(
@@ -357,6 +371,7 @@ class DatasetModels(collections.abc.Sequence):
 
     @property
     def covariance(self):
+        """Covariance (`~gammapy.modeling.Covariance`)"""
         self._check_covariance()
 
         for model in self._models:
@@ -375,6 +390,7 @@ class DatasetModels(collections.abc.Sequence):
 
     @property
     def parameters(self):
+        """Parameters (`~gammapy.modeling.Parameters`)"""
         return Parameters.from_stack([_.parameters for _ in self._models])
 
     @property
@@ -391,6 +407,7 @@ class DatasetModels(collections.abc.Sequence):
 
     @property
     def names(self):
+        """List of model names"""
         return [m.name for m in self._models]
 
     @classmethod
@@ -522,6 +539,8 @@ class DatasetModels(collections.abc.Sequence):
                 and "template" in model.spatial_model.tag
             ):
                 model.spatial_model.write(overwrite=overwrite_templates)
+            if model.tag == "TemplateNPredModel":
+                model.write(overwrite=overwrite_templates)
 
         if self._covar_file is not None:
             return {
@@ -589,7 +608,6 @@ class DatasetModels(collections.abc.Sequence):
         table.write(make_path(filename), **kwargs)
 
     def __str__(self):
-
         self.update_link_label()
 
         str_ = f"{self.__class__.__name__}\n\n"
@@ -632,7 +650,6 @@ class DatasetModels(collections.abc.Sequence):
     def _ipython_key_completions_(self):
         return self.names
 
-    @copy_covariance
     def copy(self, copy_data=False):
         """A deep copy.
 
@@ -652,7 +669,9 @@ class DatasetModels(collections.abc.Sequence):
             model_copy = model.copy(name=model.name, copy_data=copy_data)
             models.append(model_copy)
 
-        return self.__class__(models=models)
+        return self.__class__(
+            models=models, covariance_data=self.covariance.data.copy()
+        )
 
     def select(
         self,
