@@ -5,6 +5,7 @@ import os
 import numpy as np
 import scipy.integrate
 import scipy.special
+from scipy.interpolate import griddata
 import astropy.units as u
 from astropy.coordinates import Angle, SkyCoord
 from astropy.coordinates.angle_utilities import angular_separation, position_angle
@@ -17,10 +18,12 @@ from regions import (
     RectangleSkyRegion,
 )
 import matplotlib.pyplot as plt
-from gammapy.maps import Map, WcsGeom
-from gammapy.modeling import Parameter
-from gammapy.modeling.covariance import copy_covariance
+from gammapy.maps import Map, MapCoord, WcsGeom
+from gammapy.modeling import Parameter, Parameters
+from gammapy.utils.deprecation import deprecated
 from gammapy.utils.gauss import Gauss2DPDF
+from gammapy.utils.interpolation import interpolation_scale
+from gammapy.utils.regions import region_circle_to_ellipse, region_to_frame
 from gammapy.utils.scripts import make_path
 from .core import ModelBase
 
@@ -35,6 +38,7 @@ __all__ = [
     "ShellSpatialModel",
     "SpatialModel",
     "TemplateSpatialModel",
+    "PiecewiseNormSpatialModel",
 ]
 
 
@@ -158,11 +162,12 @@ class SpatialModel(ModelBase):
         Parameters
         ----------
         geom : `~gammapy.maps.WcsGeom`
+            Map geometry
 
         Returns
         -------
-        `~gammapy.maps.Map`
-
+        map : `~gammapy.maps.Map`
+            Map containing the value in each spatial bin.
         """
         coords = geom.get_coord(frame=self.frame, sparse=True)
 
@@ -192,8 +197,8 @@ class SpatialModel(ModelBase):
 
         Returns
         -------
-        `~gammapy.maps.Map` or `gammapy.maps.RegionNDMap`, containing
-                the integral value in each spatial bin.
+        map : `~gammapy.maps.Map` or `gammapy.maps.RegionNDMap`
+            Map containing the integral value in each spatial bin.
         """
         wcs_geom = geom
         mask = None
@@ -300,6 +305,7 @@ class SpatialModel(ModelBase):
             )
         return m.plot(ax=ax, **kwargs)
 
+    @deprecated("v1.0.1", alternative="plot_interactive")
     def plot_interative(self, ax=None, geom=None, **kwargs):
         """Plot spatial model.
 
@@ -323,6 +329,29 @@ class SpatialModel(ModelBase):
             raise TypeError("Use .plot() for 2D Maps")
         m.plot_interactive(ax=ax, **kwargs)
 
+    def plot_interactive(self, ax=None, geom=None, **kwargs):
+        """Plot spatial model.
+
+        Parameters
+        ----------
+        ax : `~matplotlib.axes.Axes`, optional
+            Axis
+        geom : `~gammapy.maps.WcsGeom`, optional
+            Geom to use for plotting.
+        **kwargs : dict
+            Keyword arguments passed to `~gammapy.maps.WcsMap.plot()`
+
+        Returns
+        -------
+        ax : `~matplotlib.axes.Axes`, optional
+            Axis
+        """
+
+        m = self._get_plot_map(geom)
+        if m.geom.is_image:
+            raise TypeError("Use .plot() for 2D Maps")
+        m.plot_interactive(ax=ax, **kwargs)
+
     def plot_error(self, ax=None, **kwargs):
         """Plot position error
 
@@ -381,7 +410,7 @@ class SpatialModel(ModelBase):
     @classmethod
     def from_position(cls, position, **kwargs):
         """Define the position of the model using a sky coord
-
+           The model will be created in the frame of the sky coord
         Parameters
         ----------
         position : `~astropy.coordinates.SkyCoord`
@@ -393,7 +422,7 @@ class SpatialModel(ModelBase):
             Spatial model
         """
         lon_0, lat_0 = position.data.lon, position.data.lat
-        return cls(lon_0=lon_0, lat_0=lat_0, frame=position.frame, **kwargs)
+        return cls(lon_0=lon_0, lat_0=lat_0, frame=position.frame.name, **kwargs)
 
     @property
     def evaluation_radius(self):
@@ -775,6 +804,43 @@ class DiskSpatialModel(SpatialModel):
             **kwargs,
         )
 
+    @classmethod
+    def from_region(cls, region, **kwargs):
+        """Create a `DiskSpatialModel from a ~regions.EllipseSkyRegion`
+
+        Parameters
+        ----------
+        region : `~regions.EllipseSkyRegion` or ~regions.CircleSkyRegion`
+            region to create model from
+        kwargs : keywords passed to `~gammapy.modeling.models.DiskSpatialModel`
+
+        Returns
+        -------
+        spatial_model : `~gammapy.modeling.models.DiskSpatialModel`
+        """
+        if isinstance(region, CircleSkyRegion):
+            region = region_circle_to_ellipse(region)
+        if not isinstance(region, EllipseSkyRegion):
+            raise ValueError(
+                f"Please provide a `CircleSkyRegion` "
+                f"or `EllipseSkyRegion`, got {type(region)} instead."
+            )
+        frame = kwargs.pop("frame", region.center.frame)
+        region = region_to_frame(region, frame=frame)
+
+        if region.height > region.width:
+            major_axis, minor_axis = region.height, region.width
+            phi = region.angle
+        else:
+            minor_axis, major_axis = region.height, region.width
+            phi = 90 * u.deg + region.angle
+
+        kwargs.setdefault("phi", phi)
+        kwargs.setdefault("e", np.sqrt(1.0 - np.power(minor_axis / major_axis, 2)))
+        kwargs.setdefault("r_0", major_axis / 2.0)
+
+        return cls.from_position(region.center, **kwargs)
+
 
 class ShellSpatialModel(SpatialModel):
     r"""Shell model.
@@ -1029,6 +1095,8 @@ class TemplateSpatialModel(SpatialModel):
     copy_data : bool
         Create a deepcopy of the map data or directly use the original. True by
         default, can be turned to False to save memory in case of large maps.
+    **kwargs : dict
+        Keyword arguments forwarded to `SpatialModel.__init__`.
     """
 
     tag = ["TemplateSpatialModel", "template"]
@@ -1041,6 +1109,7 @@ class TemplateSpatialModel(SpatialModel):
         interp_kwargs=None,
         filename=None,
         copy_data=True,
+        **kwargs,
     ):
         if (map.data < 0).any():
             log.warning("Map has negative values. Check and fix this!")
@@ -1080,9 +1149,8 @@ class TemplateSpatialModel(SpatialModel):
 
         self._interp_kwargs = interp_kwargs
         self.filename = filename
-        super().__init__()
+        super().__init__(**kwargs)
 
-    @copy_covariance
     def copy(self, copy_data=False, **kwargs):
         """Copy model
 
@@ -1190,7 +1258,7 @@ class TemplateSpatialModel(SpatialModel):
     def write(self, overwrite=False):
         if self.filename is None:
             raise IOError("Missing filename")
-        elif os.path.isfile(self.filename) and not overwrite:
+        elif os.path.isfile(make_path(self.filename)) and not overwrite:
             log.warning("Template file already exits, and overwrite is False")
         else:
             self.map.write(self.filename, overwrite=overwrite)
@@ -1209,7 +1277,128 @@ class TemplateSpatialModel(SpatialModel):
             geom = self.map.geom
         super().plot(ax=ax, geom=geom, **kwargs)
 
+    @deprecated("v1.0.1", alternative="plot_interactive")
     def plot_interative(self, ax=None, geom=None, **kwargs):
         if geom is None:
             geom = self.map.geom
-        super().plot_interative(ax=ax, geom=geom, **kwargs)
+        super().plot_interactive(ax=ax, geom=geom, **kwargs)
+
+    def plot_interactive(self, ax=None, geom=None, **kwargs):
+        if geom is None:
+            geom = self.map.geom
+        super().plot_interactive(ax=ax, geom=geom, **kwargs)
+
+
+class PiecewiseNormSpatialModel(SpatialModel):
+    """Piecewise spatial correction
+       with a free normalization at each fixed nodes.
+
+       For more information see :ref:`piecewise-norm-spatial`.
+
+    Parameters
+    ----------
+    coord : `gammapy.maps.MapCoord`
+        Flat coordinates list at which the model values are given (nodes).
+    norms : `~numpy.ndarray` or list of `Parameter`
+        Array with the initial norms of the model at energies ``energy``.
+        A normalisation parameters is created for each value.
+        Default is one at each node.
+    interp : str
+        Interpolation scaling in {"log", "lin"}. Default is "lin"
+    """
+
+    tag = ["PiecewiseNormSpatialModel", "piecewise-norm"]
+
+    def __init__(self, coords, norms=None, interp="lin", **kwargs):
+        self._coords = coords
+        self._interp = interp
+
+        if norms is None:
+            norms = np.ones(coords.shape)
+
+        if len(norms) != coords.shape[0]:
+            raise ValueError("dimension mismatch")
+
+        if len(norms) < 4:
+            raise ValueError("Input arrays must contain at least 4 elements")
+
+        if self.is_energy_dependent:
+            raise ValueError("Energy dependent nodes are not supported")
+
+        if not isinstance(norms[0], Parameter):
+            parameters = Parameters(
+                [Parameter(f"norm_{k}", norm) for k, norm in enumerate(norms)]
+            )
+        else:
+            parameters = Parameters(norms)
+        self.default_parameters = parameters
+        super().__init__(**kwargs)
+
+    @property
+    def coords(self):
+        """Energy nodes"""
+        return self._coords
+
+    @property
+    def norms(self):
+        """Norm values"""
+        return u.Quantity([p.quantity for p in self.parameters])
+
+    @property
+    def is_energy_dependent(self):
+        keys = self.coords._data.keys()
+        return "energy" in keys or "energy_true" in keys
+
+    def evaluate(self, lon, lat, energy=None, **norms):
+        """Evaluate the model at given coordinates."""
+        scale = interpolation_scale(scale=self._interp)
+        v_nodes = scale(self.norms.value)
+        coords = [value.value for value in self.coords._data.values()]
+        # TODO: apply axes scaling in this loop
+        coords = list(zip(*coords))
+        # by default rely on CloughTocher2DInterpolator
+        # (Piecewise cubic, C1 smooth, curvature-minimizing interpolant)
+        interpolated = griddata(coords, v_nodes, (lon, lat), method="cubic")
+        return scale.inverse(interpolated) * self.norms.unit
+
+    def evaluate_geom(self, geom):
+        """Evaluate model on `~gammapy.maps.Geom`
+
+        Parameters
+        ----------
+        geom : `~gammapy.maps.WcsGeom`
+            Map geometry
+
+        Returns
+        -------
+        map : `~gammapy.maps.Map`
+            Map containing the value in each spatial bin.
+
+        """
+        coords = geom.get_coord(frame=self.frame, sparse=True)
+        return self(coords.lon, coords.lat)
+
+    def to_dict(self, full_output=False):
+        data = super().to_dict(full_output=full_output)
+        for key, value in self.coords._data.items():
+            data["spatial"][key] = {
+                "data": value.data.tolist(),
+                "unit": str(value.unit),
+            }
+        return data
+
+    @classmethod
+    def from_dict(cls, data):
+        """Create model from dict"""
+        data = data["spatial"]
+        lon = u.Quantity(data["lon"]["data"], data["lon"]["unit"])
+        lat = u.Quantity(data["lat"]["data"], data["lat"]["unit"])
+        coords = MapCoord.create((lon, lat))
+
+        parameters = Parameters.from_dict(data["parameters"])
+        return cls.from_parameters(parameters, coords=coords, frame=data["frame"])
+
+    @classmethod
+    def from_parameters(cls, parameters, **kwargs):
+        """Create model from parameters"""
+        return cls(norms=parameters, **kwargs)
