@@ -437,26 +437,34 @@ def test_model_plot_sed_type():
     with mpl_plot_check():
         ax1 = pwl.plot((1 * u.TeV, 100 * u.TeV), sed_type="dnde")
         ax2 = pwl.plot_error((1 * u.TeV, 100 * u.TeV), sed_type="dnde")
-        assert ax1.axes.axes.get_ylabel() == "dnde [1 / (cm2 s TeV)]"
-        assert ax2.axes.axes.get_ylabel() == "dnde [1 / (cm2 s TeV)]"
+        assert ax1.yaxis.units == u.Unit("1 / (s cm2 TeV)")
+        assert ax1.axes.axes.get_ylabel().split()[0] == "dnde"
+        assert ax2.yaxis.units == u.Unit("1 / (s cm2 TeV)")
+        assert ax2.axes.axes.get_ylabel().split()[0] == "dnde"
 
     with mpl_plot_check():
         ax1 = pwl.plot((1 * u.TeV, 100 * u.TeV), sed_type="e2dnde")
         ax2 = pwl.plot_error((1 * u.TeV, 100 * u.TeV), sed_type="e2dnde")
-        assert ax1.axes.axes.get_ylabel() == "e2dnde [erg / (cm2 s)]"
-        assert ax2.axes.axes.get_ylabel() == "e2dnde [erg / (cm2 s)]"
+        assert ax1.yaxis.units == u.Unit("erg / (cm2 s)")
+        assert ax1.axes.axes.get_ylabel().split()[0] == "e2dnde"
+        assert ax2.yaxis.units == u.Unit("erg / (cm2 s)")
+        assert ax2.axes.axes.get_ylabel().split()[0] == "e2dnde"
 
     with mpl_plot_check():
         ax1 = pwl.plot((1 * u.TeV, 100 * u.TeV), sed_type="flux")
         ax2 = pwl.plot_error((1 * u.TeV, 100 * u.TeV), sed_type="flux")
-        assert ax1.axes.axes.get_ylabel() == "flux [1 / (cm2 s)]"
-        assert ax2.axes.axes.get_ylabel() == "flux [1 / (cm2 s)]"
+        assert ax1.yaxis.units == u.Unit("1 / (s cm2)")
+        assert ax1.axes.axes.get_ylabel().split()[0] == "flux"
+        assert ax2.yaxis.units == u.Unit("1 / (s cm2)")
+        assert ax2.axes.axes.get_ylabel().split()[0] == "flux"
 
     with mpl_plot_check():
         ax1 = pwl.plot((1 * u.TeV, 100 * u.TeV), sed_type="eflux")
         ax2 = pwl.plot_error((1 * u.TeV, 100 * u.TeV), sed_type="eflux")
-        assert ax1.axes.axes.get_ylabel() == "eflux [erg / (cm2 s)]"
-        assert ax2.axes.axes.get_ylabel() == "eflux [erg / (cm2 s)]"
+        assert ax1.yaxis.units == u.Unit("erg / (cm2 s)")
+        assert ax1.axes.axes.get_ylabel().split()[0] == "eflux"
+        assert ax2.yaxis.units == u.Unit("erg / (cm2 s)")
+        assert ax2.axes.axes.get_ylabel().split()[0] == "eflux"
 
 
 def test_to_from_dict():
@@ -670,6 +678,27 @@ def test_template_spectral_model_compound():
     assert np.allclose(new_model(energy), 2 * values)
 
 
+def test_evaluate_spectral_model_compound():
+    energy = [1.00e06, 1.25e06, 1.58e06, 1.99e06] * u.MeV
+    model = TEST_MODELS[-2]["model"]
+    values = model.evaluate(energy, *[p.quantity for p in model.parameters])
+    assert_allclose(values, model(energy))
+
+    model = TEST_MODELS[-3]["model"]
+    values = model.evaluate(energy, *[p.quantity for p in model.parameters])
+    assert_allclose(values, model(energy))
+
+
+def test_evaluate_nested_spectral_model_compound():
+    energy = [1.00e06, 1.25e06, 1.58e06, 1.99e06] * u.MeV
+    model1 = TEST_MODELS[-2]["model"]
+    model2 = TEST_MODELS[-3]["model"]
+
+    model = model1 + model2
+    values = model.evaluate(energy, *[p.quantity for p in model.parameters])
+    assert_allclose(values, model(energy))
+
+
 @requires_dependency("naima")
 class TestNaimaModel:
     # Used to test model value at 2 TeV
@@ -886,7 +915,7 @@ class TestSpectralModelErrorPropagation:
     https://nbviewer.jupyter.org/github/gammapy/gammapy-extra/blob/master/experiments/uncertainty_estimation_prototype.ipynb
     """
 
-    def setup(self):
+    def setup_method(self):
         self.model = LogParabolaSpectralModel(
             amplitude=3.76e-11 * u.Unit("cm-2 s-1 TeV-1"),
             reference=1 * u.TeV,
@@ -932,6 +961,18 @@ class TestSpectralModelErrorPropagation:
         assert_allclose(out.data, [4.119e-11, 8.157e-12], rtol=1e-3)
 
 
+def test_logpar_index_error():
+    model = LogParabolaSpectralModel(
+        amplitude=3.81e-11 / u.cm**2 / u.s / u.TeV,
+        reference=1 * u.TeV,
+        alpha=2.19,
+        beta=0.226,
+    )
+    model.alpha.error = 0.4
+    out = model.spectral_index_error(energy=1.0 * u.TeV)
+    assert_allclose(out, [2.19, 0.4], rtol=1e-3)
+
+
 def test_dnde_error_ecpl_model():
     # Regression test for ECPL model
     # https://github.com/gammapy/gammapy/issues/2007
@@ -1129,3 +1170,9 @@ def test_template_ND_EBL(tmpdir):
     assert_allclose(template_new.map.data, region_map.data)
     assert len(template.parameters) == 1
     assert_allclose(template.parameters["redshift"].value, 0.1)
+
+
+def test_is_norm_spectral_models():
+    for test_model in TEST_MODELS:
+        m = test_model["model"]
+        assert np.any([p.is_norm for p in m.parameters])
