@@ -38,7 +38,7 @@ def test_parameter_outside_limit(caplog):
 
 def test_parameter_scale():
     # Basic check how scale is used for value, min, max
-    par = Parameter("spam", 42, "deg", 10, 400, 500)
+    par = Parameter("spam", 420, "deg", 10, 400, 500)
 
     assert par.value == 420
     assert par.min == 400
@@ -52,7 +52,7 @@ def test_parameter_scale():
 
 
 def test_parameter_quantity():
-    par = Parameter("spam", 42, "deg", 10)
+    par = Parameter("spam", 420, "deg", 10)
 
     quantity = par.quantity
     assert quantity.unit == "deg"
@@ -247,10 +247,10 @@ def test_update_from_dict():
     }
     par.update_from_dict(data)
     assert par.name == "test"
-    assert par.factor == 3
-    assert par.value == 3e-10
+    assert_allclose(par.factor, 3)
+    assert_allclose(par.value, 3e-10)
     assert par.unit == "GeV"
-    assert par.min == 0
+    assert_allclose(par.min, 0)
     assert par.max is np.nan
     assert par.frozen
     data = {
