@@ -61,6 +61,35 @@ class CountsStatistic(abc.ABC):
         """
         return 0.5 * chi2.sf(self.ts, 1)
 
+    def __str__(self):
+        str_ = "\t{:32}: {{n_on:.2f}} \n".format("Total counts")
+        str_ += "\t{:32}: {{background:.2f}}\n".format("Total background counts")
+        str_ += "\t{:32}: {{excess:.2f}}\n".format("Total excess counts")
+        str_ += "\t{:32}: {{significance:.2f}}\n".format("Total significance")
+        str_ += "\t{:32}: {{p_value:.3f}}\n".format("p - value")
+        str_ += "\t{:32}: {{n_bins:.0f}}\n".format("Total number of bins")
+        info = self.info_dict()
+        info["n_bins"] = np.array(self.n_on).size
+        str_ = str_.format(**info)
+
+        return str_.expandtabs(tabsize=2)
+
+    def info_dict(self):
+        """A dictionary of the relevant quantities
+
+        Returns
+        -------
+        info_dict : dict
+            Dictionary with summary info
+        """
+        info_dict = {}
+        info_dict["n_on"] = self.n_on
+        info_dict["background"] = self.n_bkg
+        info_dict["excess"] = self.n_sig
+        info_dict["significance"] = self.sqrt_ts
+        info_dict["p_value"] = self.p_value
+        return info_dict
+
     def compute_errn(self, n_sigma=1.0):
         """Compute downward excess uncertainties.
 
@@ -250,6 +279,26 @@ class CashCountsStatistic(CountsStatistic):
         """Stat value for best fit hypothesis, i.e. expected signal mu = n_on - mu_bkg"""
         return cash(self.n_on, self.n_on)
 
+    def info_dict(self):
+        """A dictionary of the relevant quantities
+
+        Returns
+        -------
+        info_dict : dict
+            Dictionary with summary info
+        """
+        info_dict = super().info_dict()
+        info_dict["mu_bkg"] = self.mu_bkg
+        return info_dict
+
+    def __str__(self):
+        str_ = f"{self.__class__.__name__}\n"
+        str_ += super().__str__()
+        str_ += "\t{:32}: {:.2f} \n".format(
+            "Predicted background counts", self.info_dict()["mu_bkg"]
+        )
+        return str_.expandtabs(tabsize=2)
+
     def _stat_fcn(self, mu, delta=0, index=None):
         return cash(self.n_on[index], self.mu_bkg[index] + mu) - delta
 
@@ -320,6 +369,31 @@ class WStatCountsStatistic(CountsStatistic):
         """
         return wstat(self.n_on, self.n_off, self.alpha, self.n_sig + self.mu_sig)
 
+    def info_dict(self):
+        """A dictionary of the relevant quantities
+
+        Returns
+        -------
+        info_dict : dict
+            Dictionary with summary info
+        """
+        info_dict = super().info_dict()
+        info_dict["n_off"] = self.n_off
+        info_dict["alpha"] = self.alpha
+        info_dict["mu_sig"] = self.mu_sig
+        return info_dict
+
+    def __str__(self):
+        str_ = f"{self.__class__.__name__}\n"
+        str_ += super().__str__()
+        info_dict = self.info_dict()
+        str_ += "\t{:32}: {:.2f} \n".format("Off counts", info_dict["n_off"])
+        str_ += "\t{:32}: {:.2f} \n".format("alpha ", info_dict["alpha"])
+        str_ += "\t{:32}: {:.2f} \n".format(
+            "Predicted signal counts", info_dict["mu_sig"]
+        )
+        return str_.expandtabs(tabsize=2)
+
     def _stat_fcn(self, mu, delta=0, index=None):
         return (
             wstat(
