@@ -3,6 +3,7 @@
 import numpy as np
 from astropy.table import Table
 from astropy.units import Quantity
+from .deprecation import deprecated
 from .units import standardise_unit
 
 __all__ = [
@@ -85,12 +86,14 @@ def table_row_to_dict(row, make_quantity=True):
     data = {}
     for name, col in row.columns.items():
         val = row[name]
+
         if make_quantity and col.unit:
             val = Quantity(val, unit=col.unit)
         data[name] = val
     return data
 
 
+@deprecated("v1.1", alternative="astropy.table.Table")
 def table_from_row_data(rows, **kwargs):
     """Helper function to create table objects from row data.
 
