@@ -3,6 +3,7 @@ import pytest
 from numpy.testing import assert_allclose
 import astropy.units as u
 from astropy.table import Column, Table
+from gammapy.utils.deprecation import GammapyDeprecationWarning
 from gammapy.utils.table import (
     table_from_row_data,
     table_row_to_dict,
@@ -43,7 +44,10 @@ def test_table_row_to_dict(table):
 
 def test_table_from_row_data():
     rows = [dict(a=1, b=1 * u.m, c="x"), dict(a=2, b=2 * u.km, c="yy")]
-    table = table_from_row_data(rows)
+
+    with pytest.warns(GammapyDeprecationWarning):
+        table = table_from_row_data(rows)
+
     assert isinstance(table, Table)
     assert table["b"].unit == "m"
     assert_allclose(table["b"].data, [1, 2000])
